@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgJob.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgJob.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -17,10 +17,10 @@
 
 class pgaJob;
 
-class dlgJob : public dlgOidProperty
+class dlgJob : public dlgAgentProperty
 {
 public:
-    dlgJob(frmMain *frame, pgaJob *j);
+    dlgJob(pgaFactory *factory, frmMain *frame, pgaJob *j);
 
     void CheckChange();
     int Go(bool modal);
@@ -29,6 +29,8 @@ public:
     wxString GetInsertSql();
     pgObject *CreateObject(pgCollection *collection);
     pgObject *GetObject();
+    
+    wxString GetHelpPage(bool forCreate) const { return wxT("pgagent-jobs"); }
 
 private:
     pgaJob *job;
@@ -45,8 +47,6 @@ private:
     void OnAddSchedule(wxCommandEvent &ev);
     void OnRemoveSchedule(wxCommandEvent &ev);
 
-       
-
     DECLARE_EVENT_TABLE();
 };
 
