@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgAggregate.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgAggregate.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -21,7 +21,7 @@ class pgAggregate;
 class dlgAggregate : public dlgTypeProperty
 {
 public:
-    dlgAggregate(frmMain *frame, pgAggregate *agg, pgSchema *sch);
+    dlgAggregate(pgaFactory *factory, frmMain *frame, pgAggregate *agg, pgSchema *sch);
     int Go(bool modal);
 
     void CheckChange();
@@ -36,8 +36,6 @@ private:
     void OnChangeType(wxCommandEvent &ev);
     void OnChangeTypeBase(wxCommandEvent &ev);
     void OnChangeTypeState(wxCommandEvent &ev);
-    
-    wxArrayString procedures;
 
     DECLARE_EVENT_TABLE();
 };
