@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgCast.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgCast.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -20,7 +20,7 @@ class pgCast;
 class dlgCast : public dlgTypeProperty
 {
 public:
-    dlgCast(frmMain *frame, pgCast *ca);
+    dlgCast(pgaFactory *factory, frmMain *frame, pgCast *ca);
     int Go(bool modal);
 
     void CheckChange();
