@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgColumn.h 4036 2005-03-19 21:29:35Z dpage $
+// RCS-ID:      $Id: dlgColumn.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -21,7 +21,7 @@ class pgTable;
 class dlgColumn : public dlgTypeProperty
 {
 public:
-    dlgColumn(frmMain *frame, pgColumn *column, pgTable *parentNode);
+    dlgColumn(pgaFactory *factory, frmMain *frame, pgColumn *column, pgTable *parentNode);
 
     void CheckChange();
     wxString GetSql();
