@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgConnect.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgConnect.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,17 +9,10 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-#ifndef dlgConnect_H
-#define dlgConnect_H
-
-// wxWindows headers
-#include <wx/wx.h>
-
-// App headers
-#include "pgAdmin3.h"
-#include "pgConn.h"
-#include "pgServer.h"
+#ifndef DLGCONNECT_H
+#define DLGCONNECT_H
 
+#include "dlgClasses.h"
 
 // Class declarations
 class dlgConnect : public DialogWithHelp
@@ -31,13 +24,12 @@ public:
 
 
     wxString GetPassword();
-    bool GetNeedPwd();
+    bool GetStorePwd();
     int Go();
     
 private:
     void OnOK(wxCommandEvent& ev);
     void OnCancel(wxCommandEvent& ev);
-    void OnTrustChange(wxCommandEvent& ev);
     DECLARE_EVENT_TABLE()
 };
 
