@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgDatabase.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgDatabase.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -20,7 +20,7 @@ class pgDatabase;
 class dlgDatabase : public dlgSecurityProperty
 {
 public:
-    dlgDatabase(frmMain *frame, pgDatabase *db);
+    dlgDatabase(pgaFactory *factory, frmMain *frame, pgDatabase *db);
     int Go(bool modal);
 
     void CheckChange();
@@ -43,6 +43,8 @@ private:
     void OnVarnameSelChange(wxCommandEvent &ev);
 
     DECLARE_EVENT_TABLE();
+
+    friend class pgDatabaseFactory;
 };
 
 
