@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgDomain.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgDomain.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -21,7 +21,7 @@ class pgDomain;
 class dlgDomain : public dlgTypeProperty
 {
 public:
-    dlgDomain(frmMain *frame, pgDomain *dom, pgSchema *sch);
+    dlgDomain(pgaFactory *factory, frmMain *frame, pgDomain *dom, pgSchema *sch);
     int Go(bool modal);
 
     void CheckChange();
