@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgForeignKey.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgForeignKey.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -22,15 +22,15 @@ class pgTable;
 class dlgForeignKey : public dlgCollistProperty
 {
 public:
-    dlgForeignKey(frmMain *frame, pgForeignKey *node, pgTable *parentNode);
-    dlgForeignKey(frmMain *frame, ctlListView *colList);
+    dlgForeignKey(pgaFactory *factory, frmMain *frame, pgForeignKey *node, pgTable *parentNode);
+    dlgForeignKey(pgaFactory *factory, frmMain *frame, ctlListView *colList);
 
     void CheckChange();
     wxString GetSql();
     wxString GetDefinition();
     pgObject *CreateObject(pgCollection *collection);
     pgObject *GetObject();
-    wxString GetHelpPage() const { return wxT("sql-altertable"); }
+    wxString GetHelpPage() const { return wxT("pg/sql-altertable"); }
 
     int Go(bool modal);
 
@@ -46,6 +46,7 @@ private:
     void OnSelChangeRefCol(wxCommandEvent &ev);
     void OnAddRef(wxCommandEvent &ev);
     void OnRemoveRef(wxCommandEvent &ev);
+    void OnOK(wxCommandEvent &ev);
 
     DECLARE_EVENT_TABLE();
 };
