@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgIndex.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgIndex.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -17,12 +17,13 @@
 
 
 class pgIndex;
+class pgIndexBase;
 
 class dlgIndexBase : public dlgCollistProperty
 {
 public:
-    dlgIndexBase(frmMain *frame, const wxString &resName, pgIndex *index, pgTable *parentNode);
-    dlgIndexBase(frmMain *frame, const wxString &resName, ctlListView *colList);
+    dlgIndexBase(pgaFactory *factory, frmMain *frame, const wxString &resName, pgIndexBase *index, pgTable *parentNode);
+    dlgIndexBase(pgaFactory *factory, frmMain *frame, const wxString &resName, ctlListView *colList);
 
     void CheckChange();
     pgObject *GetObject();
@@ -30,7 +31,7 @@ public:
     int Go(bool modal);
 
 protected:
-    pgIndex *index;
+    pgIndexBase *index;
 
 private:
     void OnAddCol(wxCommandEvent &ev);
@@ -43,7 +44,7 @@ private:
 class dlgIndex : public dlgIndexBase
 {
 public:
-    dlgIndex(frmMain *frame, pgIndex *index, pgTable *parentNode);
+    dlgIndex(pgaFactory *factory, frmMain *frame, pgIndex *index, pgTable *parentNode);
 
     int Go(bool modal);
     void CheckChange();
@@ -55,5 +56,4 @@ private:
 };
 
 
-
 #endif
