@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgOperator.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgOperator.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -21,7 +21,7 @@ class pgOperator;
 class dlgOperator : public dlgTypeProperty
 {
 public:
-    dlgOperator(frmMain *frame, pgOperator *op, pgSchema *sch);
+    dlgOperator(pgaFactory *factory, frmMain *frame, pgOperator *op, pgSchema *sch);
     int Go(bool modal);
 
     void CheckChange();
