@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgProperty.h 4014 2005-03-04 21:15:52Z dpage $
+// RCS-ID:      $Id: dlgProperty.h 4586 2005-10-21 16:34:10Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -22,6 +22,7 @@ class pgSchema;
 class pgTable;
 class frmMain;
 class ctlSecurityPanel;
+class pgaFactory;
 
 #define stComment       CTRL_STATIC("stComment")
 #define lstColumns      CTRL_LISTVIEW("lstColumns")
@@ -30,8 +31,9 @@ class ctlSecurityPanel;
 class dlgProperty : public DialogWithHelp
 {
 public:
-    static bool CreateObjectDialog(frmMain *frame, pgObject *node, int type);
+    static bool CreateObjectDialog(frmMain *frame, pgObject *node, pgaFactory *factory=0);
     static bool EditObjectDialog(frmMain *frame, ctlSQLBox *sqlbox, pgObject *node);
+    void InitDialog(frmMain *frame, pgObject *node);
 
     wxString GetName();
 
@@ -48,14 +50,14 @@ public:
     virtual void CheckChange() =0;
 
 protected:
-    dlgProperty(frmMain *frame, const wxString &resName);
+    dlgProperty(pgaFactory *factory, frmMain *frame, const wxString &resName);
     ~dlgProperty();
 
     void EnableOK(bool enable);
     void ShowObject();
 
     void CheckValid(bool &enable, const bool condition, const wxString &msg);
-    static dlgProperty *CreateDlg(frmMain *frame, pgObject *node, bool asNew, int type=-1);
+    static dlgProperty *CreateDlg(frmMain *frame, pgObject *node, bool asNew, pgaFactory *factory=0);
     void AppendNameChange(wxString &sql, const wxString &objname=wxEmptyString);
     void AppendOwnerChange(wxString &sql, const wxString &objName=wxEmptyString);
     void AppendOwnerNew(wxString &sql, const wxString &objname);
@@ -95,12 +97,13 @@ protected:
     wxNotebook *nbNotebook;
     wxTextCtrl *txtName, *txtOid, *txtComment;
     ctlComboBox *cbOwner;
+    ctlComboBox *cbClusterSet;
 
     int width, height;
     wxTreeItemId item;
-    int objectType;
     bool readOnly;
     bool processing;
+    pgaFactory *factory;
 
 private:
     bool tryUpdate(wxTreeItemId collectionItem);
@@ -125,7 +128,7 @@ public:
     int Go(bool modal);
 
 protected:
-    dlgTypeProperty(frmMain *frame, const wxString &resName);
+    dlgTypeProperty(pgaFactory *factory, frmMain *frame, const wxString &resName);
     void CheckLenEnable();
     void FillDatatype(ctlComboBox *cb, bool withDomains=true);
     void FillDatatype(ctlComboBox *cb, ctlComboBox *cb2, bool withDomains=true);
@@ -145,8 +148,8 @@ public:
     int Go(bool modal);
 
 protected:
-    dlgCollistProperty(frmMain *frame, const wxString &resName, pgTable *table);
-    dlgCollistProperty(frmMain *frame, const wxString &resName, ctlListView *colList);
+    dlgCollistProperty(pgaFactory *factory, frmMain *frame, const wxString &resName, pgTable *table);
+    dlgCollistProperty(pgaFactory *factory, frmMain *frame, const wxString &resName, ctlListView *colList);
 
     ctlListView *columns;
     pgTable *table;
@@ -156,7 +159,7 @@ protected:
 class dlgSecurityProperty : public dlgProperty
 {
 protected:
-    dlgSecurityProperty(frmMain *frame, pgObject *obj, const wxString &resName, const wxString& privilegeList, char *privilegeChar);
+    dlgSecurityProperty(pgaFactory *factory, frmMain *frame, pgObject *obj, const wxString &resName, const wxString& privilegeList, char *privilegeChar);
     ~dlgSecurityProperty();
     void AddGroups(ctlComboBox *comboBox=0);
     void AddUsers(ctlComboBox *comboBox=0);
@@ -180,21 +183,65 @@ private:
 
 
 
-class dlgOidProperty : public dlgProperty
+class dlgAgentProperty : public dlgProperty
 {
 public:
 
 protected:
-    dlgOidProperty(frmMain *frame, const wxString &resName);
+    dlgAgentProperty(pgaFactory *factory, frmMain *frame, const wxString &resName);
     void OnOK(wxCommandEvent &ev);
     bool executeSql();
     virtual wxString GetInsertSql() =0;
     virtual wxString GetUpdateSql() =0;
     wxString GetSql();
+    long GetRecId() { return recId; }
 
     DECLARE_EVENT_TABLE();
 
-    OID oid;
+    long recId;
+};
+
+
+class propertyFactory : public contextActionFactory
+{
+public:
+    propertyFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
+};
+
+
+class createFactory : public actionFactory
+{
+public:
+    createFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
+};
+
+class dropFactory : public contextActionFactory
+{
+public:
+    dropFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
+};
+
+
+class dropCascadedFactory : public contextActionFactory
+{
+public:
+    dropCascadedFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
+};
+
+class refreshFactory : public contextActionFactory
+{
+public:
+    refreshFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
 };
 
 
