@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgUser.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgUser.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -14,15 +14,15 @@
 #define __DLG_USERPROP
 
 #include "dlgProperty.h"
-#include "calbox.h"
-#include "timespin.h"
+#include "ctl/calbox.h"
+#include "ctl/timespin.h"
 
 class pgUser;
 
 class dlgUser : public dlgProperty
 {
 public:
-    dlgUser(frmMain *frame, pgUser *node=0);
+    dlgUser(pgaFactory *factory, frmMain *frame, pgUser *node=0);
 
     void CheckChange();
     wxString GetSql();
@@ -39,6 +39,7 @@ private:
     void OnChangeSuperuser(wxCommandEvent &ev);
     void OnChangeSpin(wxSpinEvent &ev);
     void OnChangeCal(wxCalendarEvent &ev);
+    void OnChangeDate(wxDateEvent &ev);
     void OnGroupAdd(wxCommandEvent &ev);
     void OnGroupRemove(wxCommandEvent &ev);
 
@@ -47,6 +48,7 @@ private:
     void OnVarSelChange(wxListEvent &ev);
 
     void OnVarnameSelChange(wxCommandEvent &ev);
+    void OnChangePasswd(wxCommandEvent &ev);
 
     wxArrayString groupsIn;
 
