@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgView.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: dlgView.h 4410 2005-08-21 11:53:02Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -22,7 +22,7 @@ class ctlSQLBox;
 class dlgView : public dlgSecurityProperty
 {
 public:
-    dlgView(frmMain *frame, pgView *v, pgSchema *sch);
+    dlgView(pgaFactory *factory, frmMain *frame, pgView *v, pgSchema *sch);
     int Go(bool modal);
 
     void CheckChange();
