@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmEditGrid.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: frmEditGrid.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,7 +15,7 @@
 #include <wx/grid.h>
 
 #define CTL_EDITGRID 357
-
+#include "dlgClasses.h"
 
 class cacheLine
 {
@@ -79,7 +79,7 @@ public:
 #if wxCHECK_VERSION(2,5,0)
     // problems are fixed
 #else
-    bool SetTable(wxGridTableBase *table, bool takeOwnership=FALSE);
+    bool SetTable(wxGridTableBase *table, bool takeOwnership=false);
 #endif
 };
 
@@ -148,6 +148,8 @@ private:
 };
 
 
+class frmMain;
+class pgSchemaObject;
 
 class frmEditGrid : public pgFrame
 {
@@ -197,5 +199,33 @@ private:
 
     DECLARE_EVENT_TABLE();
 };
+
+
+class editGridFactoryBase : public contextActionFactory
+{
+public:
+    bool CheckEnable(pgObject *obj);
+
+protected:
+    editGridFactoryBase(menuFactoryList *list) : contextActionFactory(list) {}
+    wxWindow *ViewData(frmMain *form, pgObject *obj, bool filter);
+};
+
+
+class editGridFactory : public editGridFactoryBase
+{
+public:
+    editGridFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+};
+
+
+class editGridFilteredFactory : public editGridFactoryBase
+{
+public:
+    editGridFilteredFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+};
+
 #endif
 
