@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmGrantWizard.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: frmGrantWizard.h 4467 2005-09-26 14:31:20Z dpage $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -12,14 +12,9 @@
 #ifndef FRMGRANTWIZARD_H
 #define FRMGRANTWIZARD_H
 
-// wxWindows headers
-#include <wx/wx.h>
-
-
-// App headers
-#include "pgAdmin3.h"
-#include "frmMain.h"
-
+#include <wx/notebook.h>
+#include "dlgClasses.h"
+#include "base/factory.h"
 
 class ctlSecurityPanel;
 
@@ -50,4 +45,12 @@ private:
     DECLARE_EVENT_TABLE()
 };
 
+class grantWizardFactory : public contextActionFactory
+{
+public:
+    grantWizardFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
+};
+
 #endif
