@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmHelp.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: frmHelp.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,6 +15,8 @@
 
 #include "wx/wxhtml.h"
 
+#include "dlgClasses.h"
+#include "base/factory.h"
 
 class ctlHelpWindow;
 class frmMain;
@@ -52,4 +54,36 @@ private:
     frmHelp *helpForm;
 };
 
+
+class contentsFactory : public actionFactory
+{
+public:
+    contentsFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+};
+
+
+class pgsqlHelpFactory : public actionFactory
+{
+public:
+    pgsqlHelpFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar, bool bigTool);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+};
+
+
+class faqFactory : public actionFactory
+{
+public:
+    faqFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+};
+
+
+class bugReportFactory : public actionFactory
+{
+public:
+    bugReportFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+};
+
 #endif
