@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmIndexcheck.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: frmIndexcheck.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,15 +9,11 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-#ifndef FRMINDEXCHECK_H
-#define FRMINDEXCHECK_H
+#ifndef __FRMINDEXCHECK_H
+#define __FRMINDEXCHECK_H
 
-// wxWindows headers
-#include <wx/wx.h>
-
-// App headers
-#include "pgAdmin3.h"
-#include "frmMain.h"
+#include "dlgClasses.h"
+#include "base/factory.h"
 
 
 // Class declarations
@@ -44,4 +40,13 @@ private:
     DECLARE_EVENT_TABLE()
 };
 
+
+class indexCheckFactory : public contextActionFactory
+{
+public:
+    indexCheckFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
+};
+
 #endif
