@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmMain.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: frmMain.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,23 +15,21 @@
 
 // wxWindows headers
 #include <wx/wx.h>
-#include <wx/treectrl.h>
 #include <wx/listctrl.h>
 #include <wx/notebook.h>
 
-// App headers
-#include "pgAdmin3.h"
-#include "ctlSQLBox.h"
-#include "pgServer.h"
-#include "pgCollection.h"
-#include "pgDatabase.h"
-#include "pgSchema.h"
+#include "dlgClasses.h"
+#include "base/factory.h"
 
+class pgServer;
+class pgServerCollection;
+class ctlSQLBox;
+class ctlTree;
 class wxSplitterWindow;
 class dlgProperty;
+class serverCollection;
 
-WX_DECLARE_LIST(wxWindow, windowList);
-
+class propertyFactory;
 
 // Class declarations
 class frmMain : public pgFrame
@@ -39,82 +37,66 @@ class frmMain : public pgFrame
 public:
     frmMain(const wxString& title);
     ~frmMain();
-    void OnTipOfTheDay(wxCommandEvent& event);
+    void OnAction(wxCommandEvent &ev);
+    wxString GetHelpPage() const;
 
     void StartMsg(const wxString& msg);
-    void EndMsg();
+    void EndMsg(bool done=true);
     void SetStatusText(const wxString &msg);
     void SetCurrentObject(pgObject *data) { currentObject = data; }
-
-    void SetButtons(pgObject *obj=0);
+    bool CheckAlive();
 
     void execSelChange(wxTreeItemId item, bool currentNode);
     void Refresh(pgObject *data);
-    void RemoveFrame(wxWindow *frame);
-    void SetDatabase(pgDatabase *newDatabase) { m_database = newDatabase; }
+    void ExecDrop(bool cascaded);
+    void ShowObjStatistics(pgObject *data, int sel);
 
-    wxImageList *GetImageList() { return images; }
-    wxTreeCtrl *GetBrowser() { return browser; }
+    wxImageList *GetImageList() { return imageList; }
+    ctlTree *GetBrowser() { return browser; }
     ctlSQLBox *GetSqlPane() { return sqlPane; }
     ctlListView *GetProperties() { return properties; }
     ctlListView *GetStatistics();
     ctlListView *GetDependsOn();
     ctlListView *GetReferencedBy();
+    void StoreServers();
+    int ReconnectServer(pgServer *server);
+    void ReportConnError(pgServer *server);
+    pgServerCollection *GetServerCollection() { return serversObj; }
 
 private:
-    windowList frames;
-    wxTreeCtrl *browser;
+    ctlTree *browser;
     ctlListView *properties;
     ctlListView *statistics;
     ctlListView *referencedBy, *dependsOn;
     wxNotebook *listViews;
     ctlSQLBox *sqlPane;
-    wxMenu *newMenu, *toolsMenu, *viewMenu, *treeContextMenu, *newContextMenu;
-    wxTreeItemId servers;
-	wxImageList *images;
+    wxMenu *newMenu, *toolsMenu, *viewMenu, *treeContextMenu, *newContextMenu, *slonyMenu;
+    pgServerCollection *serversObj;
     wxSplitterWindow *horizontal, *vertical;
 
+    propertyFactory *propFactory;
+    actionFactory *newMenuFactory;
+
     wxStopWatch stopwatch;
     wxString timermsg;
     long msgLevel;
 
     wxTreeItemId denyCollapseItem;
     pgObject *currentObject;
-    pgDatabase *m_database;
 
     void OnContents(wxCommandEvent& event);
-    void OnHelp(wxCommandEvent& event);
-    void OnPgsqlHelp(wxCommandEvent& event);
-    void OnFaq(wxCommandEvent& event);
-    void OnAddServer(wxCommandEvent &ev);
     void OnExit(wxCommandEvent& event);
-    void OnViewData(wxCommandEvent& event);
-    void OnViewFilteredData(wxCommandEvent& event);
 	void ViewData(bool filter = false);
-    void OnOptions(wxCommandEvent& event);
-    void OnPassword(wxCommandEvent& event);
     void OnSaveDefinition(wxCommandEvent& event);
     void OnShowSystemObjects(wxCommandEvent& event);
-    void OnSql(wxCommandEvent& event);
-    void OnMaintenance(wxCommandEvent& event);
-    void OnIndexcheck(wxCommandEvent& event);
-    void OnGrantWizard(wxCommandEvent& event);
-    void OnStatus(wxCommandEvent& event);
-    void OnBackup(wxCommandEvent& event);
-    void OnRestore(wxCommandEvent& event);
-    void OnCount(wxCommandEvent& event);
     void OnContextMenu(wxCommandEvent& event);
 
-    void OnConfig(wxCommandEvent& event);
-    void OnHbaConfig(wxCommandEvent& event);
-
     void OnPageChange(wxNotebookEvent& event);
     void OnPropSelChanged(wxListEvent& event);
     void OnPropSelActivated(wxListEvent& event);
     void OnPropRightClick(wxListEvent& event);
     void OnTreeSelChanged(wxTreeEvent &event);
     void OnTreeKeyDown(wxTreeEvent& event);
-    void OnConnect(wxCommandEvent &ev);
     void OnSelActivated(wxTreeEvent& event);
     void OnSelRightClick(wxTreeEvent& event);
     void OnCollapse(wxTreeEvent& event);
@@ -122,35 +104,24 @@ private:
     void OnClose(wxCloseEvent& event);
 
     void OnNew(wxCommandEvent& event);
-    void OnCreate(wxCommandEvent &ev);
-    void OnDrop(wxCommandEvent &ev);
     void OnDelete(wxCommandEvent &ev);
-    void OnProperties(wxCommandEvent &ev);
-    void OnStartService(wxCommandEvent &ev);
-    void OnStopService(wxCommandEvent &ev);
-    void OnRefresh(wxCommandEvent &ev);
-    void OnDisconnect(wxCommandEvent &ev);
 
     void OnCheckAlive(wxCommandEvent& event);
+    void OnOnlineUpdate(wxCommandEvent& event);
+    void OnOnlineUpdateNewData(wxCommandEvent& event);
 
-    bool dropSingleObject(pgObject *data, bool updateFinal);
+    bool dropSingleObject(pgObject *data, bool updateFinal, bool cascaded);
     void doPopup(wxWindow *win, wxPoint point, pgObject *object);
+    void enableSubmenu(int id);
     void appendIfEnabled(int id);
-    bool checkAlive();
     void setDisplay(pgObject *data, ctlListView *props=0, ctlSQLBox *sqlbox=0);
-    void StoreServers();
     void RetrieveServers();
-    int ReconnectServer(pgServer *server);
+    bool reportError(const wxString &error, const wxString &msgToIdentify, const wxString &hint);
     wxTreeItemId RestoreEnvironment(pgServer *server);
 
     DECLARE_EVENT_TABLE()
 };
 
-
-
-
-
-// Controls
 enum
 {
     CTL_BROWSER = 301,
@@ -163,12 +134,5 @@ enum
 };
 
 
-enum
-{
-    NBP_PROPERTIES=0,
-    NBP_STATISTICS,
-    NBP_DEPENDSON,
-    NBP_REFERENCEDBY
-};
 
 #endif
