@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmQuery.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: frmQuery.h 4651 2005-11-04 14:58:44Z dpage $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -12,13 +12,11 @@
 #ifndef __FRM_QUERY_H
 #define __FRM_QUERY_H
 
+#include "dlgClasses.h"
+#include "base/factory.h"
 
-
-// wxWindows headers
-#include <wx/wx.h>
-
-#include "ctlSQLResult.h"
-
+class ExplainCanvas;
+class ctlSQLResult;
 
 class frmQuery : public pgFrame
 {
@@ -33,11 +31,15 @@ private:
     ctlSQLBox *sqlQuery;
     wxNotebook *output;
     ctlSQLResult *sqlResult;
+    ExplainCanvas *explainCanvas;
     wxTextCtrl *msgResult, *msgHistory;
+    wxComboBox *cbConnection;
+
     pgConn *conn;
     wxLongLong elapsedQuery, elapsedRetrieve;
 
     void OnChangeStc(wxStyledTextEvent& event);
+    void OnPositionStc(wxStyledTextEvent& event);
     void OnClose(wxCloseEvent& event);
     void OnSetFocus(wxFocusEvent& event);
     void OnContents(wxCommandEvent& event);
@@ -58,6 +60,7 @@ private:
     void OnUndo(wxCommandEvent& event);
     void OnRedo(wxCommandEvent& event);
     void OnSaveHistory(wxCommandEvent& event);
+    void OnChangeConnection(wxCommandEvent &ev);
     void OnClearHistory(wxCommandEvent& event);
     void OnActivate(wxActivateEvent& event);
     void OnFocus(wxFocusEvent& event);
@@ -65,7 +68,7 @@ private:
     bool CheckChanged(bool canVeto);
     void OpenLastFile();
     void updateMenu(wxObject *obj=0);
-    void execQuery(const wxString &query, int resultToRetrieve=0, bool singleResult=false, const int queryOffset=0, bool toFile=false);
+    bool execQuery(const wxString &query, int resultToRetrieve=0, bool singleResult=false, const int queryOffset=0, bool toFile=false);
     void setTools(const bool running);
     void showMessage(const wxString& msg, const wxString &msgShort=wxT(""));
     void setExtendedTitle();
@@ -86,6 +89,7 @@ private:
 enum
 {
     STATUSPOS_MSGS = 1,
+    STATUSPOS_POS,
     STATUSPOS_ROWS,
     STATUSPOS_SECS
 };
@@ -100,4 +104,12 @@ enum
 };
 
 
+class queryToolFactory : public actionFactory
+{
+public:
+    queryToolFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
+};
+
 #endif // __FRM_QUERY_H
