@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmRestore.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: frmRestore.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -13,16 +13,10 @@
 #ifndef FRMRESTORE_H
 #define FRMRESTORE_H
 
-// wxWindows headers
-#include <wx/wx.h>
-
-// App headers
-#include "pgAdmin3.h"
-#include "frmMain.h"
-
-// Class declarations
-
+#include "dlgClasses.h"
+#include "base/factory.h"
 
+class pgServer;
 class frmRestore : public ExternProcessDialog
 {
 public:
@@ -56,4 +50,14 @@ private:
     DECLARE_EVENT_TABLE()
 };
 
+
+class restoreFactory : public contextActionFactory
+{
+public:
+    restoreFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
+};
+
+
 #endif
