@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmSplash.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: frmSplash.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -12,12 +12,8 @@
 #ifndef SPLASH_H
 #define SPLASH_H
 
-// wxWindows headers
-#include <wx/wx.h>
-#include <wx/image.h>
-
-// App headers
-#include "pgAdmin3.h"
+#include "dlgClasses.h"
+#include "base/factory.h"
 
 // Class declarations
 class frmSplash : public pgFrame
