@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmStatus.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: frmStatus.h 4467 2005-09-26 14:31:20Z dpage $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -17,10 +17,10 @@
 #include <wx/image.h>
 #include <wx/listctrl.h>
 #include <wx/spinctrl.h>
+#include <wx/notebook.h>
 
-// App headers
-#include "pgAdmin3.h"
-#include "frmMain.h"
+#include "dlgClasses.h"
+#include "base/factory.h"
 
 #define CTL_STATUSLIST 300
 
@@ -48,6 +48,8 @@ private:
 	void OnSelLockItem(wxListEvent &event);
 	void OnLoadLogfile(wxCommandEvent &event);
     void OnRotateLogfile(wxCommandEvent &event);
+    void OnCommit(wxCommandEvent &event);
+    void OnRollback(wxCommandEvent &event);
 
     int fillLogfileCombo();
     void emptyLogfileCombo();
@@ -74,8 +76,18 @@ private:
     wxTimer *timer;
 	bool loaded;
     long logfileLength;
+    int xactPage, logPage;
 
     DECLARE_EVENT_TABLE();
 };
 
+
+class serverStatusFactory : public actionFactory
+{
+public:
+    serverStatusFactory(menuFactoryList *list, wxMenu *mnu, wxToolBar *toolbar);
+    wxWindow *StartDialog(frmMain *form, pgObject *obj);
+    bool CheckEnable(pgObject *obj);
+};
+
 #endif
