@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgAggregate.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgAggregate.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -12,16 +12,19 @@
 #ifndef PGAGGREGATE_H
 #define PGAGGREGATE_H
 
-// wxWindows headers
-#include <wx/wx.h>
-
 // App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
-#include "pgServer.h"
-#include "pgDatabase.h"
+#include "pgSchema.h"
 
 class pgCollection;
+class pgAggregateFactory : public pgaFactory
+{
+public:
+    pgAggregateFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+    pgCollection *CreateCollection(pgObject *obj);
+};
+extern pgAggregateFactory aggregateFactory;
 
 class pgAggregate : public pgSchemaObject
 {
@@ -30,10 +33,9 @@ public:
     ~pgAggregate();
     void SetSchema(pgSchema *newSchema) { schema = newSchema; }
     pgSchema *GetSchema() const {return schema; }
-    int GetIcon() { return PGICON_AGGREGATE; }
+    bool CanDropCascaded() { return true; }
 
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
     wxString GetFullName() const;
     wxString GetInputType() const { return inputType; }
     void iSetInputType(const wxString& s) { inputType=s; }
@@ -47,14 +49,19 @@ public:
     void iSetFinalFunction(const wxString& s) { finalFunction=s; }
     wxString GetInitialCondition() { return initialCondition; }
     void iSetInitialCondition(const wxString& s) { initialCondition=s; }
+    wxString GetSortOp() { return sortOp; }
+    void iSetSortOp(const wxString &s) { sortOp=s; }
+    wxString GetQuotedSortOp() { return quotedSortOp; }
+    void iSetQuotedSortOp(const wxString &s) { quotedSortOp=s; }
 
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
-    wxString GetSql(wxTreeCtrl *browser);
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
+    wxString GetSql(ctlTree *browser);
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 private:
     pgSchema *schema;
-    wxString inputType, stateType, finalType,
+    wxString inputType, stateType, finalType, sortOp, quotedSortOp,
              stateFunction, finalFunction, initialCondition;
 };
 
