@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgCast.h 3977 2005-02-13 15:13:18Z andreas $
+// RCS-ID:      $Id: pgCast.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,19 +9,23 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-#ifndef PGCast_H
-#define PGCast_H
+#ifndef PGCAST_H
+#define PGCAST_H
 
-// wxWindows headers
-#include <wx/wx.h>
 
 // App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
-#include "pgServer.h"
 #include "pgDatabase.h"
 
 class pgCollection;
+class pgCastFactory : public pgDatabaseObjFactory
+{
+public:
+    pgCastFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+};
+extern pgCastFactory castFactory;
+
 
 class pgCast : public pgDatabaseObject
 {
@@ -29,9 +33,9 @@ public:
     pgCast(const wxString& newName = wxT(""));
     ~pgCast();
 
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
-    int GetIcon() { return PGICON_CAST; }
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
+
+    bool CanDropCascaded() { return true; }
 
     bool GetSystemObject() const { return GetOid() <= GetConnection()->GetLastSystemOID(); }
     wxString GetSourceType() const { return sourceType; }
@@ -54,9 +58,9 @@ public:
     wxString GetCastContext() const { return castContext; }
     void iSetCastContext(const wxString& s) { castContext=s; }
 
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
-    wxString GetSql(wxTreeCtrl *browser);
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
+    wxString GetSql(ctlTree *browser);
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 private:
     wxString sourceType, sourceNamespace, targetType, targetNamespace, 
