@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgColumn.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgColumn.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,32 +9,33 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-#ifndef PGColumn_H
-#define PGColumn_H
-
-// wxWindows headers
-#include <wx/wx.h>
+#ifndef PGCOLUMN_H
+#define PGCOLUMN_H
 
 // App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
-#include "pgServer.h"
-#include "pgDatabase.h"
+#include "pgTable.h"
 
 class pgCollection;
 
-class pgColumn : public pgSchemaObject
+class pgColumnFactory : public pgTableObjFactory
 {
 public:
-    pgColumn(pgSchema *newSchema, const wxString& newName = wxT(""));
+    pgColumnFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+};
+extern pgColumnFactory columnFactory;
+
+class pgColumn : public pgTableObject
+{
+public:
+    pgColumn(pgTable *newTable, const wxString& newName = wxT(""));
     ~pgColumn();
 
-    int GetIcon() { return PGICON_COLUMN; }
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
     void ShowStatistics(frmMain *form, ctlListView *statistics);
     void ShowDependsOn(frmMain *form, ctlListView *dependsOn, const wxString &where=wxEmptyString);
     void ShowReferencedBy(frmMain *form, ctlListView *referencedBy, const wxString &where=wxEmptyString);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
 
     wxString GetDefinition();
 
@@ -82,19 +83,21 @@ public:
     void iSetSerialSequence(const wxString &s) { serialSequence=s; }
     wxString GetSerialSchema() const { return serialSchema; }
     void iSetSerialSchema(const wxString &s) { serialSchema=s; }
+    void iSetPkCols(const wxString &s) { pkCols = s; }
+    void iSetIsFK(const bool b) { isFK = b; }
 
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
     bool GetSystemObject() const { return colNumber < 0; }
-    wxString GetSql(wxTreeCtrl *browser);
+    wxString GetSql(ctlTree *browser);
 	wxString GetCommentSql();
-    wxString GetHelpPage(bool forCreate) const { return wxT("sql-createtable"); }
+    wxString GetHelpPage(bool forCreate) const { return wxT("pg/sql-createtable"); }
 
     virtual bool CanDrop() { return inheritedCount == 0 && pgSchemaObject::CanDrop(); }
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 private:
     wxString varTypename, quotedTypename, defaultVal, tableName, quotedFullTable, storage, rawTypename;
-    wxString serialSequence, serialSchema;
+    wxString serialSequence, serialSchema, pkCols;
     long colNumber, length, precision, statistics, attstattarget;
     long typlen, typmod, inheritedCount;
     bool isPK, isFK, notNull, isArray;
