@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgDatabase.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgDatabase.h 4583 2005-10-20 14:49:49Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -12,14 +12,23 @@
 #ifndef PGDATABASE_H
 #define PGDATABASE_H
 
-// wxWindows headers
-#include <wx/wx.h>
-
-// App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
 #include "pgServer.h"
-#include "pgConn.h"
+
+class pgDatabaseFactory : public pgServerObjFactory
+{
+public:
+    pgDatabaseFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+    virtual pgCollection *CreateCollection(pgObject *obj);
+
+    int GetClosedIconId() { return WantSmallIcon() ? smallClosedId : closedId; }
+protected:
+    int closedId, smallClosedId;
+};
+
+extern pgDatabaseFactory databaseFactory;
+
 
 // Class declarations
 class pgDatabase : public pgServerObject
@@ -27,15 +36,14 @@ class pgDatabase : public pgServerObject
 public:
     pgDatabase(const wxString& newName = wxT(""));
     ~pgDatabase();
+    int GetIconId();
 
-    int GetIcon() { return PGICON_DATABASE; }
     pgDatabase *GetDatabase() const { return (pgDatabase*)this; }
     bool BackendMinimumVersion(int major, int minor) { return connection()->BackendMinimumVersion(major, minor); }
 
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
-    static void ShowStatistics(pgCollection *collection, ctlListView *statistics);
-    
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
+    void ShowHint(frmMain *form, bool force);
+
     pgSet *ExecuteSet(const wxString& sql);
     wxString ExecuteScalar(const wxString& sql);
     bool ExecuteVoid(const wxString& sql);
@@ -62,11 +70,13 @@ public:
     bool GetConnected() { return connected; }
     bool GetSystemObject() const;
     long GetMissingFKs() const { return missingFKs; }
+    wxArrayString GetSlonyClusters(ctlTree *browser);
     
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
-    bool CanMaintenance() { return true; }
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
+    bool CanMaintenance() { return GetConnected(); }
     bool CanBackup() { return connected; }
     bool CanRestore() { return connected; }
+    bool GetCanHint();
     bool RequireDropConfirm() { return true; }
     pgConn *connection();
     int Connect();
@@ -77,8 +87,8 @@ public:
     void ClearSchemaChanges() { schemaChanges=wxEmptyString; }
 
     wxMenu *GetNewMenu();
-    wxString GetSql(wxTreeCtrl *browser);
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+    wxString GetSql(ctlTree *browser);
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 private:
     pgConn *conn;
@@ -93,4 +103,59 @@ private:
     wxString schemaChanges;
 };
 
+class pgDatabaseCollection : public pgServerObjCollection
+{
+public:
+    pgDatabaseCollection(pgaFactory *factory, pgServer *sv);
+    void ShowStatistics(frmMain *form, ctlListView *statistics);
+};
+
+
+////////////////////////////////////////////////
+
+class pgDatabaseObjFactory : public pgServerObjFactory
+{
+public:
+    pgDatabaseObjFactory(const wxChar *tn, const wxChar *ns, const wxChar *nls, char **img, char **imgSm=0) 
+        : pgServerObjFactory(tn, ns, nls, img, imgSm) {}
+    virtual pgCollection *CreateCollection(pgObject *obj);
+};
+
+
+// Object that lives in a database
+class pgDatabaseObject : public pgObject
+{
+public:
+    pgDatabaseObject(pgaFactory &factory, const wxString& newName=wxEmptyString) : pgObject(factory, newName) {}
+    pgDatabaseObject(int newType, const wxString& newName) : pgObject(newType, newName) {}
+
+    void iSetDatabase(pgDatabase *newDatabase) { database = newDatabase; }
+    pgDatabase *GetDatabase() const { return database; }
+    pgServer *GetServer() const;
+
+    void DisplayStatistics(ctlListView *statistics, const wxString& query);
+
+    // compiles a prefix from the schema name with '.', if necessary
+    wxString GetSchemaPrefix(const wxString &schemaname) const;
+    wxString GetQuotedSchemaPrefix(const wxString &schemaname) const;
+
+    bool CanDrop();
+    bool CanEdit() { return true; }
+    bool CanCreate();
+
+protected:
+    pgDatabase *database;
+};
+
+
+// collection of pgDatabaseObject
+class pgDatabaseObjCollection : public pgCollection
+{
+public:
+    pgDatabaseObjCollection(pgaFactory *factory, pgDatabase *db);
+    bool CanCreate();
+};
+
+
+
 #endif
