@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgForeignKey.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgForeignKey.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -12,29 +12,27 @@
 #ifndef PGFOREIGNKEY_H
 #define PGFOREIGNKEY_H
 
-// wxWindows headers
-#include <wx/wx.h>
+#include "pgIndex.h"
 
-// App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
-#include "pgServer.h"
-#include "pgDatabase.h"
-
-class pgCollection;
-
-class pgForeignKey : public pgSchemaObject
+class pgForeignKeyFactory : public pgTableObjFactory
 {
 public:
-    pgForeignKey(pgSchema *newSchema, const wxString& newName = wxT(""));
+    pgForeignKeyFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+};
+extern pgForeignKeyFactory foreignKeyFactory;
+
+class pgForeignKey : public pgTableObject
+{
+public:
+    pgForeignKey(pgTable *newTable, const wxString& newName = wxT(""));
     ~pgForeignKey();
     
     wxString GetDefinition();
     wxString GetFullName() const;
 
-    int GetIcon() { return PGICON_FOREIGNKEY; }
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
 
     wxString GetOnUpdate() const { return onUpdate; }
     void iSetOnUpdate(const wxString& s) { onUpdate=s; }
@@ -57,6 +55,8 @@ public:
     void iSetDeferrable(const bool b) { deferrable=b; }
     bool GetDeferred() const { return deferred; }
     void iSetDeferred(const bool b) { deferred=b; }
+    wxString GetMatch() const { return match; }
+    void iSetMatch(const wxString &s) { match=s; }
     wxString GetRelTableOidStr() const { return NumToStr(relTableOid) + wxT("::oid"); }
     OID GetRelTableOid() const { return relTableOid; }
     void iSetRelTableOid(const OID d) { relTableOid = d; }
@@ -67,16 +67,16 @@ public:
     wxString GetQuotedRefColumns() const { return quotedRefColumns; }
     wxString GetCoveringIndex() const { return coveringIndex; }
 
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
     wxString GetConstraint();
-    wxString GetSql(wxTreeCtrl *browser);
-    wxString GetHelpPage(bool forCreate) const { return wxT("sql-altertable"); }
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+    wxString GetSql(ctlTree *browser);
+    wxString GetHelpPage(bool forCreate) const { return wxT("pg/sql-altertable"); }
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 private:
     wxString onUpdate, onDelete, conkey, confkey,
              fkTable, fkSchema, references, refSchema;
-    wxString fkColumns, refColumns, quotedFkColumns, quotedRefColumns, coveringIndex;
+    wxString fkColumns, refColumns, quotedFkColumns, quotedRefColumns, coveringIndex, match;
     bool deferrable, deferred;
     OID relTableOid;
 };
