@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgFunction.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgFunction.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,19 +9,26 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-#ifndef PGFunction_H
-#define PGFunction_H
+#ifndef PGFUNCTION_H
+#define PGFUNCTION_H
 
-// wxWindows headers
-#include <wx/wx.h>
-
-// App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
-#include "pgServer.h"
-#include "pgDatabase.h"
+#include "pgSchema.h"
 
 class pgCollection;
+class pgFunction;
+
+class pgFunctionFactory : public pgSchemaObjFactory
+{
+public:
+    pgFunctionFactory(const wxChar *tn=0, const wxChar *ns=0, const wxChar *nls=0, char **img=0);
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+
+    pgFunction *AppendFunctions(pgObject *obj, pgSchema *schema, ctlTree *browser, const wxString &restriction);
+};
+
+
+extern pgFunctionFactory functionFactory;
 
 class pgFunction : public pgSchemaObject
 {
@@ -30,10 +37,10 @@ public:
     ~pgFunction();
 
 
-    int GetIcon() { return PGICON_FUNCTION; }
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser);
-    static pgFunction *pgFunction::AppendFunctions(pgObject *obj, pgSchema *schema, wxTreeCtrl *browser, const wxString &restriction);
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
+    bool CanDropCascaded() { return true; }
+
+    virtual bool GetIsProcedure() const {return false; }
 
     wxString GetFullName() const {return GetName()+wxT("(")+GetArgTypes()+wxT(")"); }
     wxString GetArgTypeNames() const { return argTypeNames; }
@@ -47,6 +54,8 @@ public:
     wxString GetArgTypeOids() const { return argTypeOids; }
     wxArrayString &GetArgNames() { return argNames; }
     void iAddArgName(const wxString &s) { argNames.Add(s); }
+    wxArrayString &GetArgModes() { return argModes; }
+    void iAddArgMode(const wxString &s) { argModes.Add(s); }
     void iSetArgTypeOids(const wxString& s) { argTypeOids = s; }
     wxString GetReturnType() const { return returnType; }
 	wxString GetQuotedReturnType() const { return quotedReturnType; }
@@ -70,10 +79,10 @@ public:
     void iSetIsStrict(bool b) { isStrict = b; }
 
     bool CanRestore() { return true; }
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
-    wxString GetSql(wxTreeCtrl *browser);
-    wxString GetHelpPage(bool forCreate) const { return wxT("sql-createfunction"); }
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
+    wxString GetSql(ctlTree *browser);
+    wxString GetHelpPage(bool forCreate) const { return wxT("pg/sql-createfunction"); }
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 protected:
     pgFunction(pgSchema *newSchema, int newType, const wxString& newName = wxT(""));
@@ -82,17 +91,49 @@ private:
     wxString argTypeOids, argTypes, quotedArgTypes,
         argTypeNames, quotedArgTypeNames,
         returnType, quotedReturnType, language, volatility, source, bin;
-    wxArrayString argNames;
-    bool returnAsSet, secureDefiner, isStrict;
+    wxArrayString argNames, argModes;
+    bool returnAsSet, secureDefiner, isStrict, isProcedure;
     long argCount;
 };
 
+
+class pgTriggerFunctionFactory : public pgFunctionFactory
+{
+public:
+    pgTriggerFunctionFactory();
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+};
+extern pgTriggerFunctionFactory triggerFunctionFactory;
+
+
 class pgTriggerFunction : public pgFunction
 {
 public:
     pgTriggerFunction(pgSchema *newSchema, const wxString& newName = wxT(""));
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser);
-    int GetIcon() { return PGICON_TRIGGERFUNCTION; }
+    static pgObject *ReadObjects(pgCollection *collection, ctlTree *browser);
+};
+
+
+class pgProcedureFactory : public pgFunctionFactory
+{
+public:
+    pgProcedureFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+};
+extern pgProcedureFactory procedureFactory;
+
+
+class pgProcedure : public pgFunction
+{
+public:
+    pgProcedure(pgSchema *newSchema, const wxString& newName = wxT(""));
+    static pgObject *ReadObjects(pgCollection *collection, ctlTree *browser);
+
+    bool GetIsProcedure() const {return true; }
+
+    wxString GetSql(ctlTree *browser);
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
 };
 
 #endif
