@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgLanguage.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgLanguage.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,19 +9,20 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-#ifndef PGLanguage_H
-#define PGLanguage_H
+#ifndef PGLANGUAGE_H
+#define PGLANGUAGE_H
 
-// wxWindows headers
-#include <wx/wx.h>
-
-// App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
-#include "pgServer.h"
 #include "pgDatabase.h"
 
 class pgCollection;
+class pgLanguageFactory : public pgDatabaseObjFactory
+{
+public:
+    pgLanguageFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+};
+extern pgLanguageFactory languageFactory;
 
 class pgLanguage : public pgDatabaseObject
 {
@@ -29,9 +30,8 @@ public:
     pgLanguage(const wxString& newName = wxT(""));
     ~pgLanguage();
 
-    int GetIcon() { return PGICON_LANGUAGE; }
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
+    bool CanDropCascaded() { return true; }
 
     wxString GetHandlerProc() const { return handlerProc; }
     void iSetHandlerProc(const wxString& s) { handlerProc = s; }
@@ -40,9 +40,9 @@ public:
     bool GetTrusted() const { return trusted; }
     void iSetTrusted(const bool b) { trusted=b; }
 
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
-    wxString GetSql(wxTreeCtrl *browser);
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
+    wxString GetSql(ctlTree *browser);
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 private:
     wxString handlerProc, validatorProc;
