@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgOperator.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgOperator.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,29 +9,32 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-#ifndef PGOperator_H
-#define PGOperator_H
+#ifndef PG_OPERATOR_H
+#define PG_OPERATOR_H
 
-// wxWindows headers
-#include <wx/wx.h>
 
-// App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
-#include "pgServer.h"
-#include "pgDatabase.h"
+#include "pgSchema.h"
 
 
+class pgOperatorFactory : public pgSchemaObjFactory
+{
+public:
+    pgOperatorFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+};
+extern pgOperatorFactory operatorFactory;
+
 class pgOperator : public pgSchemaObject
 {
 public:
     pgOperator(pgSchema *newSchema, const wxString& newName = wxT(""));
     ~pgOperator();
 
-    int GetIcon() { return PGICON_OPERATOR; }
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
     virtual wxString GetQuotedIdentifier() const { return GetName(); }
+    bool CanDropCascaded() { return true; }
+
     wxString GetFullName() const;
     wxString GetOperands() const;
     wxString GetLeftType() const { return leftType; }
@@ -67,9 +70,9 @@ public:
     bool GetHashJoins() const { return hashJoins; }
     void iSetHashJoins(bool b) {  hashJoins=b; }
 
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
-    wxString GetSql(wxTreeCtrl *browser);
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
+    wxString GetSql(ctlTree *browser);
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 private:
     wxString leftType, rightType, resultType,
