@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgSequence.h 3970 2005-02-07 14:52:28Z andreas $
+// RCS-ID:      $Id: pgSequence.h 4523 2005-10-08 20:48:59Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,30 +9,34 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-#ifndef PGSequence_H
-#define PGSequence_H
+#ifndef PGSEQUENCE_H
+#define PGSEQUENCE_H
 
-// wxWindows headers
-#include <wx/wx.h>
 
-// App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
-#include "pgServer.h"
-#include "pgDatabase.h"
+#include "pgSchema.h"
 
-class pgCollection;
+class pgSequenceFactory : public pgSchemaObjFactory
+{
+public:
+    pgSequenceFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+    int GetReplicatedIconId() { return replicatedIconId; }
+private:
+    int replicatedIconId;
+};
+extern pgSequenceFactory sequenceFactory;
 
 class pgSequence : public pgSchemaObject
 {
 public:
     pgSequence(pgSchema *newSchema, const wxString& newName = wxT(""));
     ~pgSequence();
+    int GetIconId();
 
-    int GetIcon() { return PGICON_SEQUENCE; }
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
     void ShowStatistics(frmMain *form, ctlListView *statistics);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
+    bool CanDropCascaded() { return true; }
 
     void UpdateValues();
     wxULongLong GetLastValue() const { return lastValue; }
@@ -42,13 +46,13 @@ public:
     wxULongLong GetIncrement() const { return increment; }
     bool GetCycled() const { return cycled; }
 
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
-    wxString GetSql(wxTreeCtrl *browser);
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
+    wxString GetSql(ctlTree *browser);
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 private:
     wxULongLong lastValue, minValue, maxValue, cacheValue, increment;
-    bool cycled;
+    bool cycled, isReplicated;
 };
 
 #endif
