@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgServer.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgServer.h 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -12,27 +12,41 @@
 #ifndef PGSERVER_H
 #define PGSERVER_H
 
-// wxWindows headers
-#include <wx/wx.h>
-
-// App headers
-#include "pgAdmin3.h"
 #include "pgConn.h"
-#include "pgObject.h"
-// Class declarations
+#include "pgCollection.h"
 
 
 class frmMain;
 
+
+class pgServerFactory : public pgaFactory
+{
+public:
+    pgServerFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+    virtual pgCollection *CreateCollection(pgObject *obj);
+
+    int GetClosedIconId() { return WantSmallIcon() ? smallClosedId : closedId; }
+protected:
+    int closedId, smallClosedId;
+};
+extern pgServerFactory serverFactory;
+
+
 class pgServer : public pgObject
 {
 public:
-    pgServer(const wxString& newServer = wxT(""), const wxString& newDescription = wxT(""), const wxString& newDatabase = wxT(""), const wxString& newUsername = wxT(""), int newPort = 5432, bool trusted=false, int sslMode=0);
+    pgServer(const wxString& newServer = wxT(""), const wxString& newDescription = wxT(""), const wxString& newDatabase = wxT(""), const wxString& newUsername = wxT(""), int newPort = 5432, bool storePwd=false, int sslMode=0);
     ~pgServer();
-    int GetType() const { return PG_SERVER; }
+    int GetIconId();
+
     wxString GetTypeName() const { return wxT("Server"); }
     int Connect(frmMain *form, bool askPassword=true, const wxString &pwd=wxEmptyString);
-    bool Disconnect();
+    bool Disconnect(frmMain *form);
+    void StorePassword();
+    bool GetPasswordIsStored();
+    void InvalidatePassword() { passwordValid = false; }
 
     bool StartService();
     bool StopService();
@@ -48,8 +62,7 @@ public:
     wxString GetDatabaseName() const { return database; }
     wxString GetUsername() const { return username; }
     wxString GetPassword() const { return password; }
-    bool GetTrusted() const { return trusted; }
-    bool GetNeedPwd() const { return !trusted; }
+    bool GetStorePwd() const { return storePwd; }
     wxString GetLastError() const;
 
     bool GetDiscovered() const { return discovered; }
@@ -80,8 +93,7 @@ public:
     void iSetSSL(int newval) { ssl=newval; }
     void iSetUsername(const wxString& newVal) { username = newVal; }
     void iSetPassword(const wxString& newVal) { password = newVal; }
-    void iSetTrusted(const bool b) { trusted=b; }
-    void iSetNeedPwd(const bool b) { trusted=!b; }
+    void iSetStorePwd(const bool b) { storePwd = b; }
     bool SetPassword(const wxString& newVal);
     wxDateTime GetUpSince() { return upSince; }
     void iSetUpSince(const wxDateTime &d) { upSince = d; }
@@ -90,26 +102,29 @@ public:
     bool ExecuteVoid(const wxString& sql) { return conn->ExecuteVoid(sql); }
     wxString ExecuteScalar(const wxString& sql) { return conn->ExecuteScalar(sql); }
     pgSet *ExecuteSet(const wxString& sql) { return conn->ExecuteSet(sql); }
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
+    void ShowHint(frmMain *form, bool force);
     void ShowStatistics(frmMain *form, ctlListView *statistics);
-    wxString GetHelpPage(bool forCreate) const { return wxT("managing-databases"); }
-    int GetIcon() { return PGICON_SERVER; }
+    wxString GetHelpPage(bool forCreate) const { return wxT("pg/managing-databases"); }
     wxMenu *GetNewMenu();
 
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser) { return true; }
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded) { return true; }
+    bool GetCanHint();
     bool CanEdit() { return true; }
     bool CanDrop() { return true; }
 
     pgConn *connection() { return conn; }
     
 private:
+    wxString passwordFilename();
+
     pgConn *conn;
-    bool connected;
+    bool connected, passwordValid, autovacuumRunning;
     wxString database, username, password, ver, error;
     wxString lastDatabase, lastSchema, description, serviceId;
     wxDateTime upSince;
     int port, ssl;
-    bool trusted, discovered, createPrivilege, superUser;
+    bool storePwd, discovered, createPrivilege, superUser;
     OID lastSystemOID;
     OID dbOid;
     wxString versionNum;
@@ -117,7 +132,60 @@ private:
 #ifdef WIN32
     SC_HANDLE scmHandle;
     SC_HANDLE serviceHandle;
+    wxArrayString GetDependentServices(SC_HANDLE handle);
 #endif
 };
 
+
+// collection of pgServer
+class pgServerCollection : public pgCollection
+{
+public:
+    pgServerCollection(pgaFactory *factory);
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0) {};
+};
+
+
+///////////////////////////////////////////////
+
+
+class pgServerObjFactory : public pgaFactory
+{
+public:
+    pgServerObjFactory(const wxChar *tn, const wxChar *ns, const wxChar *nls, char **img, char **imgSm=0)
+        : pgaFactory(tn, ns, nls, img, imgSm) {}
+    virtual pgCollection *CreateCollection(pgObject *obj);
+};
+
+
+// Object that lives under a server
+class pgServerObject : public pgObject
+{
+public:
+    pgServerObject(pgaFactory &factory, const wxString& newName=wxEmptyString) : pgObject(factory, newName) {}
+    pgServerObject(int newType, const wxString& newName) : pgObject(newType, newName) {}
+
+    void iSetServer(pgServer *s) { server=s; }
+    pgServer *GetServer() const { return server; }
+
+    void FillOwned(ctlTree *browser, ctlListView *referencedBy, const wxArrayString &dblist, const wxString &query);
+
+    bool CanCreate();
+    bool CanDrop();
+    bool CanEdit() { return true; }
+
+protected:
+    pgServer *server;
+};
+
+
+// collection of pgServerObject
+class pgServerObjCollection : public pgCollection
+{
+public:
+    pgServerObjCollection(pgaFactory *factory, pgServer *server);
+    bool CanCreate();
+};
+
+
 #endif
