@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgType.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgType.h 4403 2005-08-15 08:58:47Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,19 +9,20 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-#ifndef PGType_H
-#define PGType_H
+#ifndef PGTYPE_H
+#define PGTYPE_H
 
-// wxWindows headers
-#include <wx/wx.h>
+#include "pgSchema.h"
 
-// App headers
-#include "pgAdmin3.h"
-#include "pgObject.h"
-#include "pgServer.h"
-#include "pgDatabase.h"
 
-class pgCollection;
+class pgTypeFactory : public pgSchemaObjFactory
+{
+public:
+    pgTypeFactory();
+    virtual dlgProperty *CreateDialog(frmMain *frame, pgObject *node, pgObject *parent);
+    virtual pgObject *CreateObjects(pgCollection *obj, ctlTree *browser, const wxString &restr=wxEmptyString);
+};
+extern pgTypeFactory typeFactory;
 
 class pgType : public pgSchemaObject
 {
@@ -29,9 +30,8 @@ public:
     pgType(pgSchema *newSchema, const wxString& newName = wxT(""));
     ~pgType();
 
-    int GetIcon() { return PGICON_TYPE; }
-    void ShowTreeDetail(wxTreeCtrl *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
-    static pgObject *ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction=wxT(""));
+    void ShowTreeDetail(ctlTree *browser, frmMain *form=0, ctlListView *properties=0, ctlSQLBox *sqlPane=0);
+    bool CanDropCascaded() { return true; }
 
     wxString GetInputFunction() const { return inputFunction; }
     void iSetInputFunction(const wxString& s) { inputFunction=s; }
@@ -65,9 +65,9 @@ public:
     wxString GetQuotedTypesList() const {return quotedTypesList; }
     bool GetSystemObject() const { return pgSchemaObject::GetSystemObject() || isRecordType; }
 
-    bool DropObject(wxFrame *frame, wxTreeCtrl *browser);
-    wxString GetSql(wxTreeCtrl *browser);
-    pgObject *Refresh(wxTreeCtrl *browser, const wxTreeItemId item);
+    bool DropObject(wxFrame *frame, ctlTree *browser, bool cascaded);
+    wxString GetSql(ctlTree *browser);
+    pgObject *Refresh(ctlTree *browser, const wxTreeItemId item);
 
 private:
     wxString inputFunction, outputFunction, defaultVal, element, delimiter, alignment, storage,
