@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: utffile.h 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: utffile.h 4158 2005-05-08 17:27:53Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -24,7 +24,7 @@ public:
     wxUtfFile(const wxChar *szFileName, OpenMode mode = read, wxFontEncoding encoding=wxFONTENCODING_DEFAULT);
     wxUtfFile(int fd, wxFontEncoding encoding=wxFONTENCODING_DEFAULT);
 
-    bool Create(const wxChar *szFileName, bool bOverwrite = FALSE, int access = wxS_DEFAULT, wxFontEncoding encoding=wxFONTENCODING_DEFAULT);
+    bool Create(const wxChar *szFileName, bool bOverwrite = false, int access = wxS_DEFAULT, wxFontEncoding encoding=wxFONTENCODING_DEFAULT);
     bool Open(const wxChar *szFileName, OpenMode mode = read, int access = wxS_DEFAULT, wxFontEncoding encoding=wxFONTENCODING_DEFAULT);
     void Attach(int fd, wxFontEncoding encoding=wxFONTENCODING_DEFAULT);
 
