@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgAggregate.cpp 4014 2005-03-04 21:15:52Z dpage $
+// RCS-ID:      $Id: pgAggregate.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,13 +15,11 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgAggregate.h"
-#include "pgCollection.h"
 
 
 pgAggregate::pgAggregate(pgSchema *newSchema, const wxString& newName)
-: pgSchemaObject(newSchema, PG_AGGREGATE, newName)
+: pgSchemaObject(newSchema, aggregateFactory, newName)
 {
 }
 
@@ -29,12 +27,15 @@ pgAggregate::~pgAggregate()
 {
 }
 
-bool pgAggregate::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgAggregate::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
-    return GetDatabase()->ExecuteVoid(wxT("DROP AGGREGATE ") + GetQuotedFullIdentifier() + wxT("(") + GetInputType() + wxT(");"));
+    wxString sql=wxT("DROP AGGREGATE ") + GetQuotedFullIdentifier() + wxT("(") + GetInputType() + wxT(")");
+    if (cascaded)
+        sql += wxT(" CASCADE");
+    return GetDatabase()->ExecuteVoid(sql);
 }
 
-wxString pgAggregate::GetSql(wxTreeCtrl *browser)
+wxString pgAggregate::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -47,6 +48,8 @@ wxString pgAggregate::GetSql(wxTreeCtrl *browser)
         AppendIfFilled(sql, wxT(",\n  FINALFUNC="), qtIdent(GetFinalFunction()));
         if (GetInitialCondition().length() > 0)
           sql += wxT(",\n  INITCOND=") + qtString(GetInitialCondition());
+        AppendIfFilled(sql, wxT(",\n  SORTOP="), GetQuotedSortOp());
+
         sql += wxT("\n);\n")
             + GetOwnerSql(8, 0, wxT("AGGREGATE ") + GetQuotedFullIdentifier() 
                 + wxT("(") + qtIdent(GetInputType())
@@ -71,7 +74,7 @@ wxString pgAggregate::GetFullName() const
 
 
 
-void pgAggregate::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgAggregate::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (properties)
     {
@@ -85,6 +88,8 @@ void pgAggregate::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView
         properties->AppendItem(_("State function"), GetStateFunction());
         properties->AppendItem(_("Final type"), GetFinalType());
         properties->AppendItem(_("Final function"), GetFinalFunction());
+        if (GetConnection()->BackendMinimumVersion(8,1))
+            properties->AppendItem(_("Sort operator"), GetSortOp());
         properties->AppendItem(_("Initial condition"), GetInitialCondition());
         properties->AppendItem(_("System aggregate?"), GetSystemObject());
         properties->AppendItem(_("Comment"), GetComment());
@@ -92,25 +97,25 @@ void pgAggregate::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView
 }
 
 
-pgObject *pgAggregate::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgAggregate::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *aggregate=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_AGGREGATES)
-            aggregate = ReadObjects((pgCollection*)obj, 0, wxT("\n   AND aggfnoid::oid=") + GetOidStr());
-    }
+
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        aggregate = aggregateFactory.CreateObjects(coll, 0, wxT("\n   AND aggfnoid::oid=") + GetOidStr());
+
     return aggregate;
 }
 
 
+////////////////////////////////////////////////////////////////////////
 
-pgObject *pgAggregate::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+
+pgObject *pgAggregateFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgAggregate *aggregate=0;
-    pgSet *aggregates= collection->GetDatabase()->ExecuteSet(
+    wxString sql=
         wxT("SELECT aggfnoid::oid, proname AS aggname, pg_get_userbyid(proowner) AS aggowner, aggtransfn,\n")
         wxT(        "aggfinalfn, proargtypes[0] AS aggbasetype, ")
         wxT(        "CASE WHEN (ti.typlen = -1 AND ti.typelem != 0) THEN (SELECT at.typname FROM pg_type at WHERE at.oid = ti.typelem) || '[]' ELSE ti.typname END as inputname, ")
@@ -118,8 +123,20 @@ pgObject *pgAggregate::ReadObjects(pgCollection *collection, wxTreeCtrl *browser
         wxT(        "CASE WHEN (tt.typlen = -1 AND tt.typelem != 0) THEN (SELECT at.typname FROM pg_type at WHERE at.oid = tt.typelem) || '[]' ELSE tt.typname END as transname, ")
         wxT(        "prorettype AS aggfinaltype, ")
         wxT(        "CASE WHEN (tf.typlen = -1 AND tf.typelem != 0) THEN (SELECT at.typname FROM pg_type at WHERE at.oid = tf.typelem) || '[]' ELSE tf.typname END as finalname, ")
-        wxT(        "agginitval, description\n")
-        wxT("  FROM pg_aggregate ag\n")
+        wxT(        "agginitval, description");
+
+    if (collection->GetDatabase()->BackendMinimumVersion(8, 1))
+    {
+        sql += wxT(", oprname, opn.nspname as oprnsp\n")
+               wxT("  FROM pg_aggregate ag\n")
+               wxT("  LEFT OUTER JOIN pg_operator op ON op.oid=aggsortop\n")
+               wxT("  LEFT OUTER JOIN pg_namespace opn ON opn.oid=op.oprnamespace");
+    }
+    else
+        sql +=  wxT("\n  FROM pg_aggregate ag\n");
+
+
+    pgSet *aggregates= collection->GetDatabase()->ExecuteSet(sql +
         wxT("  JOIN pg_proc pr ON pr.oid = ag.aggfnoid\n")
         wxT("  JOIN pg_type ti on ti.oid=proargtypes[0]\n")
         wxT("  JOIN pg_type tt on tt.oid=aggtranstype\n")
@@ -140,18 +157,31 @@ pgObject *pgAggregate::ReadObjects(pgCollection *collection, wxTreeCtrl *browser
             if (aggregates->GetVal(wxT("inputname")) == wxT("any"))
                 aggregate->iSetInputType(wxT("\"any\""));
             else
-            aggregate->iSetInputType(aggregates->GetVal(wxT("inputname")));
+                aggregate->iSetInputType(aggregates->GetVal(wxT("inputname")));
             aggregate->iSetStateType(aggregates->GetVal(wxT("transname")));
             aggregate->iSetStateFunction(aggregates->GetVal(wxT("aggtransfn")));
             aggregate->iSetFinalType(aggregates->GetVal(wxT("finalname")));
-            aggregate->iSetFinalFunction(aggregates->GetVal(wxT("aggfinalfn")));
+
+            wxString final=aggregates->GetVal(wxT("aggfinalfn"));
+            if (final != wxT("-"))
+                aggregate->iSetFinalFunction(final);
             aggregate->iSetInitialCondition(aggregates->GetVal(wxT("agginitval")));
             aggregate->iSetComment(aggregates->GetVal(wxT("description")));
-
+            if (collection->GetDatabase()->BackendMinimumVersion(8, 1))
+            {
+                wxString oprname=aggregates->GetVal(wxT("oprname"));
+                if (!oprname.IsEmpty())
+                {
+                    wxString oprnsp=aggregates->GetVal(wxT("oprnsp"));
+                    aggregate->iSetSortOp(collection->GetDatabase()->GetSchemaPrefix(oprnsp) + oprname);
+                    aggregate->iSetQuotedSortOp(collection->GetDatabase()->GetQuotedSchemaPrefix(oprnsp)
+                        + qtIdent(oprname));
+                }
+            }
 
             if (browser)
             {
-                collection->AppendBrowserItem(browser, aggregate);
+                browser->AppendObject(collection, aggregate);
                             aggregates->MoveNext();
             }
             else
@@ -162,3 +192,21 @@ pgObject *pgAggregate::ReadObjects(pgCollection *collection, wxTreeCtrl *browser
     }
     return aggregate;
 }
+
+
+#include "images/aggregate.xpm"
+#include "images/aggregate-sm.xpm"
+#include "images/aggregates.xpm"
+
+pgAggregateFactory::pgAggregateFactory() 
+: pgaFactory(__("Aggregate"), __("New Aggregate"), __("Create a new Aggregate."), aggregate_xpm, aggregate_sm_xpm)
+{
+}
+
+pgCollection *pgAggregateFactory::CreateCollection(pgObject *obj)
+{
+    return new pgSchemaObjCollection(GetCollectionFactory(), (pgSchema*)obj);
+}
+
+pgAggregateFactory aggregateFactory;
+static pgaCollectionFactory cf(&aggregateFactory, __("Aggregates"), aggregates_xpm);
