@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgCast.cpp 3977 2005-02-13 15:13:18Z andreas $
+// RCS-ID:      $Id: pgCast.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,12 +15,10 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgCast.h"
-#include "pgCollection.h"
 
 pgCast::pgCast(const wxString& newName)
-: pgDatabaseObject(PG_CAST, newName)
+: pgDatabaseObject(castFactory, newName)
 {
 }
 
@@ -28,12 +26,15 @@ pgCast::~pgCast()
 {
 }
 
-bool pgCast::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgCast::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
-    return GetDatabase()->ExecuteVoid(wxT("DROP CAST (") + GetSourceType() + wxT(" AS ") + GetTargetType() + wxT(")"));
+    wxString sql=wxT("DROP CAST (") + GetSourceType() + wxT(" AS ") + GetTargetType() + wxT(")");
+    if (cascaded)
+        sql += wxT(" CASCADE");
+    return GetDatabase()->ExecuteVoid(sql);
 }
 
-wxString pgCast::GetSql(wxTreeCtrl *browser)
+wxString pgCast::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -54,7 +55,7 @@ wxString pgCast::GetSql(wxTreeCtrl *browser)
     return sql;
 }
 
-void pgCast::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgCast::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (properties)
     {
@@ -77,22 +78,20 @@ void pgCast::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *pro
 
 
 
-pgObject *pgCast::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgCast::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *cast=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_CASTS)
-            cast = ReadObjects((pgCollection*)obj, 0, wxT(" WHERE ca.oid=") + GetOidStr());
-    }
+
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        cast = castFactory.CreateObjects(coll, 0, wxT(" WHERE ca.oid=") + GetOidStr());
+
     return cast;
 }
 
 
 
-pgObject *pgCast::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+pgObject *pgCastFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgCast *cast=0;
     wxString systemRestriction;
@@ -142,7 +141,7 @@ pgObject *pgCast::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, con
             {
             if (browser)
             {
-                collection->AppendBrowserItem(browser, cast);
+                browser->AppendObject(collection, cast);
 			    casts->MoveNext();
             }
             else
@@ -155,3 +154,19 @@ pgObject *pgCast::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, con
     }
     return cast;
 }
+
+
+/////////////////////////////
+
+#include "images/cast.xpm"
+#include "images/cast-sm.xpm"
+#include "images/casts.xpm"
+
+pgCastFactory::pgCastFactory() 
+: pgDatabaseObjFactory(__("Cast"), __("New Cast"), __("Create a new Cast."), cast_xpm, cast_sm_xpm)
+{
+}
+
+
+pgCastFactory castFactory;
+static pgaCollectionFactory cf(&castFactory, __("Casts"), casts_xpm);
