@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgConversion.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgConversion.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,13 +15,11 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgConversion.h"
-#include "pgCollection.h"
 
 
 pgConversion::pgConversion(pgSchema *newSchema, const wxString& newName)
-: pgSchemaObject(newSchema, PG_CONVERSION, newName)
+: pgSchemaObject(newSchema, conversionFactory, newName)
 {
 }
 
@@ -29,12 +27,15 @@ pgConversion::~pgConversion()
 {
 }
 
-bool pgConversion::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgConversion::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
-    return GetDatabase()->ExecuteVoid(wxT("DROP CONVERSION ") + GetQuotedFullIdentifier() + wxT(";"));
+    wxString sql=wxT("DROP CONVERSION ") + GetQuotedFullIdentifier();
+    if (cascaded)
+        sql += wxT(" CASCADE");
+    return GetDatabase()->ExecuteVoid(sql);
 }
 
-wxString pgConversion::GetSql(wxTreeCtrl *browser)
+wxString pgConversion::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -54,7 +55,7 @@ wxString pgConversion::GetSql(wxTreeCtrl *browser)
     return sql;
 }
 
-void pgConversion::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgConversion::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (properties)
     {
@@ -76,22 +77,20 @@ void pgConversion::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListVie
 
 
 
-pgObject *pgConversion::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgConversion::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *conversion=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_CONVERSIONS)
-            conversion = ReadObjects((pgCollection*)obj, 0, wxT("\n   AND co.oid=") + GetOidStr());
-    }
+
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        conversion = conversionFactory.CreateObjects(coll, 0, wxT("\n   AND co.oid=") + GetOidStr());
+
     return conversion;
 }
 
 
 
-pgObject *pgConversion::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+pgObject *pgConversionFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgConversion *conversion=0;
 
@@ -124,7 +123,7 @@ pgObject *pgConversion::ReadObjects(pgCollection *collection, wxTreeCtrl *browse
 
             if (browser)
             {
-                collection->AppendBrowserItem(browser, conversion);
+                browser->AppendObject(collection, conversion);
 			    conversions->MoveNext();
             }
             else
@@ -135,3 +134,16 @@ pgObject *pgConversion::ReadObjects(pgCollection *collection, wxTreeCtrl *browse
     }
     return conversion;
 }
+
+
+#include "images/conversion.xpm"
+#include "images/conversions.xpm"
+
+pgConversionFactory::pgConversionFactory() 
+: pgSchemaObjFactory(__("Conversion"), __("New Conversion"), __("Create a new Conversion."), conversion_xpm)
+{
+}
+
+
+pgConversionFactory conversionFactory;
+static pgaCollectionFactory cf(&conversionFactory, __("Conversions"), conversions_xpm);
