@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgDatatype.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgDatatype.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -75,8 +75,8 @@ pgDatatype::pgDatatype(const wxString &nsp, const wxString &typname, bool isDup,
 
 wxString pgDatatype::GetSchemaPrefix(pgDatabase *db) const
 {
-    if (schema.IsEmpty())
-        return schema;
+    if (schema.IsEmpty() || (!db && schema == wxT("pg_catalog")))
+        return wxEmptyString;
 
     if (needSchema)
         return schema + wxT(".");
