@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgForeignKey.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgForeignKey.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,14 +15,11 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
-#include "pgTable.h"
 #include "pgForeignKey.h"
-#include "pgCollection.h"
+#include "pgConstraints.h"
 
-
-pgForeignKey::pgForeignKey(pgSchema *newSchema, const wxString& newName)
-: pgSchemaObject(newSchema, PG_FOREIGNKEY, newName)
+pgForeignKey::pgForeignKey(pgTable *newTable, const wxString& newName)
+: pgTableObject(newTable, foreignKeyFactory, newName)
 {
 }
 
@@ -31,7 +28,7 @@ pgForeignKey::~pgForeignKey()
 }
 
 
-bool pgForeignKey::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgForeignKey::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
     return GetDatabase()->ExecuteVoid(wxT(
         "ALTER TABLE ") + GetSchemaPrefix(fkSchema) + qtIdent(fkTable)
@@ -42,12 +39,16 @@ bool pgForeignKey::DropObject(wxFrame *frame, wxTreeCtrl *browser)
 wxString pgForeignKey::GetDefinition()
 {
     wxString sql;
-    // MATCH FULL/PARTIAL missing; where is this stored?!?
 
     sql = wxT("(") + GetQuotedFkColumns()
-        +  wxT(") REFERENCES ") + GetQuotedSchemaPrefix(GetRefSchema()) + qtIdent(GetReferences()) 
+        +  wxT(")\n      REFERENCES ") + GetQuotedSchemaPrefix(GetRefSchema()) + qtIdent(GetReferences()) 
         +  wxT(" (") + GetQuotedRefColumns()
-        +  wxT(") ON UPDATE ") + GetOnUpdate()
+        +  wxT(")");
+    
+    if (GetDatabase()->BackendMinimumVersion(7, 4) || GetMatch() == wxT("FULL"))
+        sql += wxT(" MATCH ") + GetMatch();
+
+    sql += wxT("\n      ON UPDATE ") + GetOnUpdate()
         +  wxT(" ON DELETE ") + GetOnDelete();
     if (GetDeferrable())
     {
@@ -71,7 +72,7 @@ wxString pgForeignKey::GetConstraint()
 }
 
 
-wxString pgForeignKey::GetSql(wxTreeCtrl *browser)
+wxString pgForeignKey::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -95,7 +96,7 @@ wxString pgForeignKey::GetFullName() const
     return GetName() + wxT(" -> ") + GetReferences();
 }
 
-void pgForeignKey::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgForeignKey::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (!expandedKids)
     {
@@ -134,8 +135,8 @@ void pgForeignKey::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListVie
         wxTreeItemId item=browser->GetItemParent(GetId());
         while (item)
         {
-            pgTable *table=(pgTable*)browser->GetItemData(item);
-            if (table->GetType() == PG_TABLE)
+            pgTable *table=(pgTable*)browser->GetObject(item);
+            if (table->IsCreatedBy(tableFactory))
             {
                 coveringIndex = table->GetCoveringIndex(browser, fkColumns);
                 break;
@@ -155,11 +156,13 @@ void pgForeignKey::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListVie
             + wxT("(") +GetRefColumns() + wxT(")"));
 
         properties->AppendItem(_("Covering index"), GetCoveringIndex());
+        properties->AppendItem(_("Match type"), GetMatch());
         properties->AppendItem(_("On update"), GetOnUpdate());
         properties->AppendItem(_("On delete"), GetOnDelete());
         properties->AppendItem(_("Deferrable?"), BoolToYesNo(GetDeferrable()));
-        properties->AppendItem(_("Initially?"), 
-            GetDeferred() ? wxT("DEFERRED") : wxT("IMMEDIATE"));
+        if (GetDeferrable())
+            properties->AppendItem(_("Initially?"), 
+                GetDeferred() ? wxT("DEFERRED") : wxT("IMMEDIATE"));
         properties->AppendItem(_("System foreign key?"), BoolToYesNo(GetSystemObject()));
         properties->AppendItem(_("Comment"), GetComment());
     }
@@ -168,23 +171,22 @@ void pgForeignKey::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListVie
 
 
 
-pgObject *pgForeignKey::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgForeignKey::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *foreignKey=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_CONSTRAINTS)
-            foreignKey = ReadObjects((pgCollection*)obj, 0, wxT("\n   AND ct.oid=") + GetOidStr());
-    }
+
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        foreignKey = foreignKeyFactory.CreateObjects(coll, 0, wxT("\n   AND ct.oid=") + GetOidStr());
+
     return foreignKey;
 }
 
 
 
-pgObject *pgForeignKey::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+pgObject *pgForeignKeyFactory::CreateObjects(pgCollection *coll, ctlTree *browser, const wxString &restriction)
 {
+    pgTableObjCollection *collection=(pgTableObjCollection*)coll;
     pgForeignKey *foreignKey=0;
 
     pgSet *foreignKeys= collection->GetDatabase()->ExecuteSet(
@@ -205,10 +207,9 @@ pgObject *pgForeignKey::ReadObjects(pgCollection *collection, wxTreeCtrl *browse
     {
         while (!foreignKeys->Eof())
         {
-            foreignKey = new pgForeignKey(collection->GetSchema(), foreignKeys->GetVal(wxT("conname")));
+            foreignKey = new pgForeignKey(collection->GetTable(), foreignKeys->GetVal(wxT("conname")));
 
             foreignKey->iSetOid(foreignKeys->GetOid(wxT("oid")));
-            foreignKey->iSetTableOid(collection->GetOid());
             foreignKey->iSetRelTableOid(foreignKeys->GetOid(wxT("confrelid")));
             foreignKey->iSetFkSchema(foreignKeys->GetVal(wxT("fknsp")));
             foreignKey->iSetComment(foreignKeys->GetVal(wxT("description")));
@@ -217,6 +218,7 @@ pgObject *pgForeignKey::ReadObjects(pgCollection *collection, wxTreeCtrl *browse
             foreignKey->iSetReferences(foreignKeys->GetVal(wxT("reftab")));
             wxString onUpd=foreignKeys->GetVal(wxT("confupdtype"));
             wxString onDel=foreignKeys->GetVal(wxT("confdeltype"));
+            wxString match=foreignKeys->GetVal(wxT("confmatchtype"));
             foreignKey->iSetOnUpdate(
                 onUpd.IsSameAs('a') ? wxT("NO ACTION") :
                 onUpd.IsSameAs('r') ? wxT("RESTRICT") :
@@ -229,6 +231,10 @@ pgObject *pgForeignKey::ReadObjects(pgCollection *collection, wxTreeCtrl *browse
                 onDel.IsSameAs('c') ? wxT("CASCADE") :
                 onDel.IsSameAs('d') ? wxT("SET DEFAULT") :
                 onDel.IsSameAs('n') ? wxT("SET NULL") : wxT("Unknown"));
+                foreignKey->iSetMatch(
+                        match.IsSameAs('f') ? wxT("FULL") :
+                        match.IsSameAs('u') ? wxT("SIMPLE") : wxT("Unknown"));
+
             wxString cn=foreignKeys->GetVal(wxT("conkey"));
             cn = cn.Mid(1, cn.Length()-2);
             foreignKey->iSetConkey(cn);
@@ -241,7 +247,7 @@ pgObject *pgForeignKey::ReadObjects(pgCollection *collection, wxTreeCtrl *browse
 
             if (browser)
             {
-                collection->AppendBrowserItem(browser, foreignKey);
+                browser->AppendObject(collection, foreignKey);
 	    		foreignKeys->MoveNext();
             }
             else
@@ -252,3 +258,19 @@ pgObject *pgForeignKey::ReadObjects(pgCollection *collection, wxTreeCtrl *browse
     }
     return foreignKey;
 }
+
+
+/////////////////////////////
+
+#include "images/foreignkey.xpm"
+
+
+pgForeignKeyFactory::pgForeignKeyFactory() 
+: pgTableObjFactory(__("Foreign Key"), __("New Foreign Key"), __("Create a new Foreign Key constraint."), foreignkey_xpm)
+{
+    metaType = PGM_FOREIGNKEY;
+    collectionFactory = &constraintCollectionFactory;
+}
+
+
+pgForeignKeyFactory foreignKeyFactory;
