@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgFunction.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgFunction.cpp 4586 2005-10-21 16:34:10Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,13 +15,11 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgFunction.h"
-#include "pgCollection.h"
 
 
 pgFunction::pgFunction(pgSchema *newSchema, const wxString& newName)
-: pgSchemaObject(newSchema, PG_FUNCTION, newName)
+: pgSchemaObject(newSchema, functionFactory, newName)
 {
 }
 
@@ -30,9 +28,12 @@ pgFunction::~pgFunction()
 }
 
 
-bool pgFunction::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgFunction::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
-    return GetDatabase()->ExecuteVoid(wxT("DROP FUNCTION ") + GetQuotedFullIdentifier()  + wxT("(") + GetQuotedArgTypes() + wxT(");"));
+    wxString sql=wxT("DROP FUNCTION ") + GetQuotedFullIdentifier()  + wxT("(") + GetQuotedArgTypes() + wxT(")");
+    if (cascaded)
+        sql += wxT(" CASCADE");
+    return GetDatabase()->ExecuteVoid(sql);
 }
 
 pgFunction::pgFunction(pgSchema *newSchema, int newType, const wxString& newName)
@@ -41,25 +42,35 @@ pgFunction::pgFunction(pgSchema *newSchema, int newType, const wxString& newName
 }
 
 pgTriggerFunction::pgTriggerFunction(pgSchema *newSchema, const wxString& newName)
-: pgFunction(newSchema, PG_TRIGGERFUNCTION, newName)
+: pgFunction(newSchema, newName)
+{
+}
+
+pgProcedure::pgProcedure(pgSchema *newSchema, const wxString& newName)
+: pgFunction(newSchema, newName)
 {
 }
 
 
-wxString pgFunction::GetSql(wxTreeCtrl *browser)
+wxString pgFunction::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
-        wxString qtName = wxT("FUNCTION ") + GetQuotedFullIdentifier()  + wxT("(") + GetQuotedArgTypes() + wxT(")");
+        wxString qtName = GetQuotedFullIdentifier()  + wxT("(") + GetQuotedArgTypeNames() + wxT(")");
 
-        sql = wxT("-- Function: ") + GetFullIdentifier() + wxT("(") + GetArgTypeNames() + wxT(")\n\n")
-            + wxT("-- DROP ") + qtName + wxT(";")
-            + wxT("\n\nCREATE OR REPLACE ") + qtName
-            + wxT("\n  RETURNS ");
-        if (GetReturnAsSet())
-            sql += wxT("SETOF ");
-        sql +=GetQuotedReturnType() 
-            + wxT(" AS\n");
+        sql = wxT("-- Function: ") + GetQuotedFullIdentifier() + wxT("(") + GetQuotedArgTypeNames() + wxT(")\n\n")
+            + wxT("-- DROP FUNCTION ") + qtName + wxT(";")
+            + wxT("\n\nCREATE OR REPLACE FUNCTION ") + qtName;
+
+        if (!GetIsProcedure())
+        {
+            sql += wxT("\n  RETURNS ");
+            if (GetReturnAsSet())
+                sql += wxT("SETOF ");
+            sql +=GetQuotedReturnType();
+        }
+
+        sql += wxT(" AS\n");
         
         if (GetLanguage().IsSameAs(wxT("C"), false))
         {
@@ -79,12 +90,12 @@ wxString pgFunction::GetSql(wxTreeCtrl *browser)
         if (GetSecureDefiner())
             sql += wxT(" SECURITY DEFINER");
         sql += wxT(";\n")
-            +  GetOwnerSql(8, 0, qtName)
-            +  GetGrant(wxT("X"), qtName);
+            +  GetOwnerSql(8, 0, wxT("FUNCTION ") + qtName)
+            +  GetGrant(wxT("X"), wxT("FUNCTION ") + qtName);
 
         if (!GetComment().IsNull())
         {
-            sql += wxT("COMMENT ON ") + qtName
+            sql += wxT("COMMENT ON FUNCTION ") + qtName
                 + wxT(" IS ") + qtString(GetComment()) + wxT(";\n");
         }
     }
@@ -93,7 +104,7 @@ wxString pgFunction::GetSql(wxTreeCtrl *browser)
 }
 
 
-void pgFunction::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgFunction::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (properties)
     {
@@ -104,7 +115,8 @@ void pgFunction::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView
         properties->AppendItem(_("Owner"), GetOwner());
         properties->AppendItem(_("Argument count"), GetArgCount());
         properties->AppendItem(_("Arguments"), GetArgTypeNames());
-        properties->AppendItem(_("Return type"), GetReturnType());
+        if (!GetIsProcedure())
+            properties->AppendItem(_("Return type"), GetReturnType());
         properties->AppendItem(_("Language"), GetLanguage());
         properties->AppendItem(_("Returns a set?"), GetReturnAsSet());
         if (GetLanguage().IsSameAs(wxT("C"), false))
@@ -125,9 +137,46 @@ void pgFunction::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView
 }
 
 
+wxString pgProcedure::GetSql(ctlTree *browser)
+{
+    if (!GetConnection()->EdbMinimumVersion(8, 0))
+        return pgFunction::GetSql(browser);
+
+    if (sql.IsNull())
+    {
+        wxString qtName = GetQuotedFullIdentifier() + wxT("(") + GetQuotedArgTypeNames() + wxT(")");
+
+        sql = wxT("-- Procedure: ") + GetQuotedFullIdentifier() + wxT("\n\n")
+            + wxT("-- DROP PROCEDURE") + GetQuotedFullIdentifier() + wxT(";")
+            + wxT("\n\nCREATE OR REPLACE ") + qtName 
+            + wxT(" AS\n")
+            + qtStringDollar(GetSource())
+            + wxT(";\n");
+
+        if (!GetComment().IsNull())
+        {
+            sql += wxT("COMMENT ON FUNCTION ") + qtName
+                + wxT(" IS ") + qtString(GetComment()) + wxT(";\n");
+        }
+    }
+
+    return sql;
+}
 
 
-pgFunction *pgFunction::AppendFunctions(pgObject *obj, pgSchema *schema, wxTreeCtrl *browser, const wxString &restriction)
+bool pgProcedure::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
+{
+    if (!GetConnection()->EdbMinimumVersion(8, 0))
+        return pgFunction::DropObject(frame, browser, cascaded);
+
+    wxString sql=wxT("DROP PROCEDURE ") + GetQuotedFullIdentifier();
+    return GetDatabase()->ExecuteVoid(sql);
+}
+
+
+
+
+pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema, ctlTree *browser, const wxString &restriction)
 {
     pgFunction *function=0;
     wxString argNamesCol;
@@ -152,37 +201,67 @@ pgFunction *pgFunction::AppendFunctions(pgObject *obj, pgSchema *schema, wxTreeC
     {
         while (!functions->Eof())
         {
-            if (functions->GetVal(wxT("typname")).IsSameAs(wxT("trigger")))
+            bool isProcedure=false;
+            wxString lanname=functions->GetVal(wxT("lanname"));
+            if (obj->GetConnection()->EdbMinimumVersion(8, 0) && lanname == wxT("edbspl"))
+                isProcedure=true;
+
+            wxString oids=functions->GetVal(wxT("proargtypes"));
+            wxStringTokenizer args(oids);
+            wxStringTokenizer modes(wxEmptyString);
+
+            wxString argNames;
+
+            if (obj->GetConnection()->BackendMinimumVersion(7, 5))
+                argNames = functions->GetVal(wxT("proargnames"));
+
+            if (obj->GetConnection()->EdbMinimumVersion(8, 0) && isProcedure)
+            {
+                wxString argDirs=functions->GetVal(wxT("proargdirs"));
+                modes.SetString(argDirs);
+            }
+            if (obj->GetConnection()->BackendMinimumVersion(8, 1))
+            {
+                wxString allArgTypes=functions->GetVal(wxT("proallargtypes"));
+                if (!allArgTypes.IsEmpty())
+                    args.SetString(allArgTypes.Mid(1, allArgTypes.Length()-2), wxT(","));
+
+                wxString argModes= functions->GetVal(wxT("proargmodes"));
+                if (!argModes.IsEmpty())
+                {
+                    modes.SetString(argModes.Mid(1, argModes.Length()-2), wxT(","));
+                    isProcedure=true;
+                }
+            }
+
+            if (isProcedure)
+                function = new pgProcedure(schema, functions->GetVal(wxT("proname")));
+            else if (functions->GetVal(wxT("typname")).IsSameAs(wxT("trigger")))
                 function = new pgTriggerFunction(schema, functions->GetVal(wxT("proname")));
             else
                 function = new pgFunction(schema, functions->GetVal(wxT("proname")));
 
-            function->iSetOid(functions->GetOid(wxT("oid")));
-            function->iSetOwner(functions->GetVal(wxT("funcowner")));
-            function->iSetAcl(functions->GetVal(wxT("proacl")));
-            function->iSetArgCount(functions->GetLong(wxT("pronargs")));
-            function->iSetReturnType(obj->GetDatabase()->GetSchemaPrefix(functions->GetVal(wxT("typnsp"))) + functions->GetVal(wxT("typname")));
-			function->iSetQuotedReturnType(obj->GetDatabase()->GetQuotedSchemaPrefix(functions->GetVal(wxT("typnsp"))) + qtIdent(functions->GetVal(wxT("typname"))));
-            function->iSetComment(functions->GetVal(wxT("description")));
-            wxString oids=functions->GetVal(wxT("proargtypes"));
-            wxString argNames;
-            if (obj->GetConnection()->BackendMinimumVersion(7, 5))
-                argNames = functions->GetVal(wxT("proargnames"));
-            function->iSetArgTypeOids(oids);
 
-            wxString str, argTypes, quotedArgTypes, argTypeNames, quotedArgTypeNames;
-            wxStringTokenizer args(oids);
+            wxString type, name, argTypes, quotedArgTypes, argTypeNames, quotedArgTypeNames, mode;
             wxStringTokenizer names(argNames.Mid(1, argNames.Length()-2), wxT(","));
+
+            
             while (args.HasMoreTokens())
             {
-                str = args.GetNextToken();
+                type = args.GetNextToken();
 
                 if (types)
                 {
                     types->MoveFirst();
-                    while (types->GetVal(wxT("oid")) != str)
+                    while (types->GetVal(wxT("oid")) != type)
+                    {
+                        if (types->Eof())
+                        {
+                            wxLogError(wxT("Internal Error while checking function args"));
+                            return 0;
+                        }
                         types->MoveNext();
-
+                    }
                     if (!argTypes.IsNull())
                     {
                         argTypes += wxT(", ");
@@ -190,12 +269,32 @@ pgFunction *pgFunction::AppendFunctions(pgObject *obj, pgSchema *schema, wxTreeC
                         argTypeNames += wxT(", ");
                         quotedArgTypeNames += wxT(", ");
                     }
-                    str = names.GetNextToken();
-                    if (!str.IsNull())
+                    name = names.GetNextToken();
+                    if (name[0] == '"')
+                        name = name.Mid(1, name.Length()-2);
+
+                    mode = modes.GetNextToken();
+                    
+                    if (!mode.IsNull())
                     {
-                        function->iAddArgName(str);
-                        argTypeNames += str + wxT(" ");
-                        quotedArgTypeNames += qtIdent(str) + wxT(" ");
+                        if (mode == wxT('o') || mode == wxT("2"))
+                            mode = wxT("OUT");
+                        else if (mode == wxT("b"))
+                            mode = wxT("INOUT");
+                        else if (mode == wxT("3"))
+                            mode = wxT("IN OUT");
+                        else
+                            mode = wxT("IN");
+
+                        function->iAddArgMode(mode);
+                        argTypeNames += mode + wxT(" ");
+                        quotedArgTypeNames += mode + wxT(" ");
+                    }
+                    if (!name.IsNull())
+                    {
+                        function->iAddArgName(name);
+                        argTypeNames += name + wxT(" ");
+                        quotedArgTypeNames += qtIdent(name) + wxT(" ");
                     }
 
     				argTypeNames += obj->GetDatabase()->GetSchemaPrefix(types->GetVal(wxT("nspname"))) + types->GetVal(wxT("typname"));
@@ -205,17 +304,28 @@ pgFunction *pgFunction::AppendFunctions(pgObject *obj, pgSchema *schema, wxTreeC
                 }
             }
 
+            function->iSetOid(functions->GetOid(wxT("oid")));
+            function->UpdateSchema(browser, functions->GetOid(wxT("pronamespace")));
+            function->iSetOwner(functions->GetVal(wxT("funcowner")));
+            function->iSetAcl(functions->GetVal(wxT("proacl")));
+            function->iSetArgCount(functions->GetLong(wxT("pronargs")));
+            function->iSetReturnType(obj->GetDatabase()->GetSchemaPrefix(functions->GetVal(wxT("typnsp"))) + functions->GetVal(wxT("typname")));
+			function->iSetQuotedReturnType(obj->GetDatabase()->GetQuotedSchemaPrefix(functions->GetVal(wxT("typnsp"))) + qtIdent(functions->GetVal(wxT("typname"))));
+            function->iSetComment(functions->GetVal(wxT("description")));
+            function->iSetArgTypeOids(oids);
+
             function->iSetArgTypes(argTypes);
             function->iSetQuotedArgTypes(quotedArgTypes);
             function->iSetArgTypeNames(argTypeNames);
             function->iSetQuotedArgTypeNames(quotedArgTypeNames);
 
-            function->iSetLanguage(functions->GetVal(wxT("lanname")));
+            function->iSetLanguage(lanname);
             function->iSetSecureDefiner(functions->GetBool(wxT("prosecdef")));
             function->iSetReturnAsSet(functions->GetBool(wxT("proretset")));
             function->iSetIsStrict(functions->GetBool(wxT("proisstrict")));
             function->iSetSource(functions->GetVal(wxT("prosrc")));
             function->iSetBin(functions->GetVal(wxT("probin")));
+
             wxString vol=functions->GetVal(wxT("provolatile"));
             function->iSetVolatility(
                 vol.IsSameAs(wxT("i")) ? wxT("IMMUTABLE") : 
@@ -225,7 +335,7 @@ pgFunction *pgFunction::AppendFunctions(pgObject *obj, pgSchema *schema, wxTreeC
 
             if (browser)
             {
-                obj->AppendBrowserItem(browser, function);
+                browser->AppendObject(obj, function);
 			    functions->MoveNext();
             }
             else
@@ -240,33 +350,35 @@ pgFunction *pgFunction::AppendFunctions(pgObject *obj, pgSchema *schema, wxTreeC
 
 
 
-pgObject *pgFunction::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgFunction::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *function=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_FUNCTIONS || obj->GetType() == PG_TRIGGERFUNCTIONS)
-            function = AppendFunctions((pgCollection*)obj, GetSchema(), 0, wxT(" WHERE pr.oid=") + GetOidStr() + wxT("\n"));
-    }
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        function = functionFactory.AppendFunctions(coll, GetSchema(), 0, wxT(" WHERE pr.oid=") + GetOidStr() + wxT("\n"));
+
     return function;
 }
 
 
 
-pgObject *pgFunction::ReadObjects(pgCollection *collection, wxTreeCtrl *browser)
+pgObject *pgFunctionFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restr)
 {
     wxString funcRestriction=wxT(
         " WHERE proisagg = FALSE AND pronamespace = ") + NumToStr(collection->GetSchema()->GetOid()) 
         + wxT("::oid\n   AND typname <> 'trigger'\n");
 
+    if (collection->GetConnection()->BackendMinimumVersion(8, 1))
+        funcRestriction += wxT("   AND proargmodes IS NULL");
+    else if (collection->GetConnection()->EdbMinimumVersion(8, 0))
+        funcRestriction += wxT("   AND lanname <>'edbspl' AND typname <> 'void'\n");
+
     // Get the Functions
     return AppendFunctions(collection, collection->GetSchema(), browser, funcRestriction);
 }
 
 
-pgObject *pgTriggerFunction::ReadObjects(pgCollection *collection, wxTreeCtrl *browser)
+pgObject *pgTriggerFunctionFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restr)
 {
     wxString funcRestriction=wxT(
         " WHERE proisagg = FALSE AND pronamespace = ") + NumToStr(collection->GetSchema()->GetOid()) 
@@ -275,3 +387,53 @@ pgObject *pgTriggerFunction::ReadObjects(pgCollection *collection, wxTreeCtrl *b
     // Get the Functions
     return AppendFunctions(collection, collection->GetSchema(), browser, funcRestriction);
 }
+
+
+pgObject *pgProcedureFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restr)
+{
+    wxString funcRestriction=wxT(
+        " WHERE proisagg = FALSE AND pronamespace = ") + NumToStr(collection->GetSchema()->GetOid()) 
+        + wxT("::oid\n");
+
+    if (collection->GetConnection()->BackendMinimumVersion(8, 1))
+        funcRestriction += wxT("   AND proargmodes IS NOT NULL");
+    else if (collection->GetConnection()->EdbMinimumVersion(8, 0))
+        funcRestriction += wxT("   AND lanname = 'edbspl' AND typname = 'void'\n");
+
+    // Get the Functions
+    return AppendFunctions(collection, collection->GetSchema(), browser, funcRestriction);
+}
+
+
+#include "images/function.xpm"
+#include "images/functions.xpm"
+
+pgFunctionFactory::pgFunctionFactory(const wxChar *tn, const wxChar *ns, const wxChar *nls, char **img) 
+: pgSchemaObjFactory(tn, ns, nls, img)
+{
+    metaType = PGM_FUNCTION;
+}
+
+pgFunctionFactory functionFactory(__("Function"), __("New Function"), __("Create a new Function."), function_xpm);
+static pgaCollectionFactory cf(&functionFactory, __("Functions"), functions_xpm);
+
+
+#include "images/triggerfunction.xpm"
+#include "images/triggerfunctions.xpm"
+
+pgTriggerFunctionFactory::pgTriggerFunctionFactory() 
+: pgFunctionFactory(__("Trigger Function"), __("New Trigger Function"), __("Create a new Trigger Function."), triggerfunction_xpm)
+{
+}
+
+pgTriggerFunctionFactory triggerFunctionFactory;
+static pgaCollectionFactory cft(&triggerFunctionFactory, __("Trigger Functions"), triggerfunctions_xpm);
+
+pgProcedureFactory::pgProcedureFactory() 
+: pgFunctionFactory(__("Procedure"), __("New Procedure"), __("Create a new Procedure."), function_xpm)
+{
+}
+
+
+pgProcedureFactory procedureFactory;
+static pgaCollectionFactory cfp(&procedureFactory, __("Procedures"), functions_xpm);
