@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgGroup.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgGroup.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,13 +15,11 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgGroup.h"
-#include "pgCollection.h"
 
 
 pgGroup::pgGroup(const wxString& newName)
-: pgServerObject(PG_GROUP, newName)
+: pgServerObject(groupFactory, newName)
 {
     wxLogInfo(wxT("Creating a pgGroup object"));
     memberCount=0;
@@ -32,12 +30,12 @@ pgGroup::~pgGroup()
     wxLogInfo(wxT("Destroying a pgGroup object"));
 }
 
-bool pgGroup::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgGroup::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
     return server->ExecuteVoid(wxT("DROP GROUP ") + GetQuotedFullIdentifier());
 }
 
-wxString pgGroup::GetSql(wxTreeCtrl *browser)
+wxString pgGroup::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -52,7 +50,7 @@ wxString pgGroup::GetSql(wxTreeCtrl *browser)
 }
 
 
-void pgGroup::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgGroup::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (!expandedKids)
     {
@@ -100,22 +98,19 @@ void pgGroup::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *pr
 
 
 
-pgObject *pgGroup::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgGroup::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *group=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_GROUPS)
-            group = ReadObjects((pgCollection*)obj, 0, wxT("\n WHERE grosysid=") + NumToStr(GetGroupId()));
-    }
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        group = groupFactory.CreateObjects(coll, 0, wxT("\n WHERE grosysid=") + NumToStr(GetGroupId()));
+
     return group;
 }
 
 
 
-pgObject *pgGroup::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+pgObject *pgGroupFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgGroup *group=0;
 
@@ -135,7 +130,7 @@ pgObject *pgGroup::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, co
 
             if (browser)
             {
-                collection->AppendBrowserItem(browser, group);
+                browser->AppendObject(collection, group);
 	    		groups->MoveNext();
             }
             else
@@ -146,3 +141,16 @@ pgObject *pgGroup::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, co
     }
     return group;
 }
+
+
+#include "images/group.xpm"
+#include "images/groups.xpm"
+
+pgGroupFactory::pgGroupFactory() 
+: pgServerObjFactory(__("Group"), __("New Group"), __("Create a new Group."), group_xpm)
+{
+}
+
+
+pgGroupFactory groupFactory;
+static pgaCollectionFactory cf(&groupFactory, __("Groups"), groups_xpm);
