@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgIndexConstraint.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgIndexConstraint.cpp 4463 2005-09-25 11:48:14Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,13 +15,12 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgConstraints.h"
 #include "pgIndexConstraint.h"
 
 
 
-bool pgIndexConstraint::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgIndexConstraint::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
     return GetDatabase()->ExecuteVoid(wxT(
         "ALTER TABLE ") + GetQuotedSchemaPrefix(GetIdxSchema()) + qtIdent(GetIdxTable())
@@ -61,13 +60,13 @@ wxString pgIndexConstraint::GetCreate()
 };
 
 
-wxString pgIndexConstraint::GetSql(wxTreeCtrl *browser)
+wxString pgIndexConstraint::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
         sql = wxT("-- Constraint: ") + GetQuotedFullIdentifier() 
             + wxT("\n\n-- ALTER TABLE ") + GetQuotedSchemaPrefix(GetIdxSchema()) + qtIdent(GetIdxTable())
-            + wxT(" DROP CONSTRAINT ") + GetQuotedIdentifier() 
+            + wxT(" DROP CONSTRAINT ") + GetQuotedIdentifier() + wxT(";")
             + wxT("\n\nALTER TABLE ") + GetQuotedSchemaPrefix(GetIdxSchema()) + qtIdent(GetIdxTable())
             + wxT("\n  ADD CONSTRAINT ")
             + GetCreate()
@@ -84,7 +83,7 @@ wxString pgIndexConstraint::GetSql(wxTreeCtrl *browser)
 
 
 
-void pgIndexConstraint::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgIndexConstraint::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     ReadColumnDetails();
     if (properties)
@@ -112,14 +111,38 @@ void pgIndexConstraint::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlLi
 
 
 
-pgObject *pgPrimaryKey::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &where)
+pgObject *pgPrimaryKeyFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &where)
 {
-    return pgIndex::ReadObjects(collection, browser, wxT("   AND contype='p'\n") + where);
+    return pgIndexBaseFactory::CreateObjects(collection, browser, wxT("   AND contype='p'\n") + where);
 }
 
 
-pgObject *pgUnique::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &where)
+pgObject *pgUniqueFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &where)
 {
-    return pgIndex::ReadObjects(collection, browser, wxT("   AND contype='u'\n") + where);
+    return pgIndexBaseFactory::CreateObjects(collection, browser, wxT("   AND contype='u'\n") + where);
 }
 
+
+#include "images/primarykey.xpm"
+
+pgPrimaryKeyFactory::pgPrimaryKeyFactory() 
+: pgIndexBaseFactory(__("Primary Key"), __("New Primary Key"), __("Create a new Primary Key constraint."), primarykey_xpm)
+{
+    metaType = PGM_PRIMARYKEY;
+    collectionFactory = &constraintCollectionFactory;
+}
+
+
+pgPrimaryKeyFactory primaryKeyFactory;
+
+#include "images/unique.xpm"
+
+pgUniqueFactory::pgUniqueFactory() 
+: pgIndexBaseFactory(__("Unique"), __("New Unique Constraint"), __("Create a new Unique constraint."), unique_xpm)
+{
+    metaType = PGM_UNIQUE;
+    collectionFactory = &constraintCollectionFactory;
+}
+
+
+pgUniqueFactory uniqueFactory;
