@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgLanguage.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgLanguage.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,13 +15,11 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgLanguage.h"
-#include "pgCollection.h"
 
 
 pgLanguage::pgLanguage(const wxString& newName)
-: pgDatabaseObject(PG_LANGUAGE, newName)
+: pgDatabaseObject(languageFactory, newName)
 {
     wxLogInfo(wxT("Creating a pgLanguage object"));
 }
@@ -31,12 +29,15 @@ pgLanguage::~pgLanguage()
     wxLogInfo(wxT("Destroying a pgLanguage object"));
 }
 
-bool pgLanguage::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgLanguage::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
-    return GetDatabase()->ExecuteVoid(wxT("DROP LANGUAGE ") + GetQuotedFullIdentifier() + wxT(";"));
+    wxString sql=wxT("DROP LANGUAGE ") + GetQuotedFullIdentifier();
+    if (cascaded)
+        sql += wxT(" CASCADE");
+    return GetDatabase()->ExecuteVoid(sql);
 }
 
-wxString pgLanguage::GetSql(wxTreeCtrl *browser)
+wxString pgLanguage::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -53,7 +54,7 @@ wxString pgLanguage::GetSql(wxTreeCtrl *browser)
     return sql;
 }
 
-void pgLanguage::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgLanguage::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (properties)
     {
@@ -73,22 +74,19 @@ void pgLanguage::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView
 
 
 
-pgObject *pgLanguage::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgLanguage::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *language=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_LANGUAGES)
-            language = ReadObjects((pgCollection*)obj, 0, wxT("\n   AND lan.oid=") + GetOidStr());
-    }
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        language = languageFactory.CreateObjects(coll, 0, wxT("\n   AND lan.oid=") + GetOidStr());
+
     return language;
 }
 
 
 
-pgObject *pgLanguage::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+pgObject *pgLanguageFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgLanguage *language=0;
 
@@ -118,7 +116,7 @@ pgObject *pgLanguage::ReadObjects(pgCollection *collection, wxTreeCtrl *browser,
 
             if (browser)
             {
-                collection->AppendBrowserItem(browser, language);
+                browser->AppendObject(collection, language);
 	
 			    languages->MoveNext();
             }
@@ -130,3 +128,19 @@ pgObject *pgLanguage::ReadObjects(pgCollection *collection, wxTreeCtrl *browser,
     }
     return language;
 }
+
+
+///////////////////////////////////////////////////
+
+#include "images/language.xpm"
+#include "images/language-sm.xpm"
+#include "images/languages.xpm"
+
+pgLanguageFactory::pgLanguageFactory() 
+: pgDatabaseObjFactory(__("Language"), __("New Language"), __("Create a new Language."), language_xpm, language_sm_xpm)
+{
+}
+
+
+pgLanguageFactory languageFactory;
+static pgaCollectionFactory cf(&languageFactory, __("Languages"), languages_xpm);
