@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgSequence.cpp 3970 2005-02-07 14:52:28Z andreas $
+// RCS-ID:      $Id: pgSequence.cpp 4523 2005-10-08 20:48:59Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,23 +15,33 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgSequence.h"
-#include "pgCollection.h"
 
 
 pgSequence::pgSequence(pgSchema *newSchema, const wxString& newName)
-: pgSchemaObject(newSchema, PG_SEQUENCE, newName)
+: pgSchemaObject(newSchema, sequenceFactory, newName)
 {
+    isReplicated=false;
 }
 
 pgSequence::~pgSequence()
 {
 }
 
-bool pgSequence::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+int pgSequence::GetIconId()
 {
-    return GetDatabase()->ExecuteVoid(wxT("DROP SEQUENCE ") + GetQuotedFullIdentifier() + wxT(";"));
+    if (isReplicated)
+        return sequenceFactory.GetReplicatedIconId();
+    else
+        return sequenceFactory.GetIconId();
+}
+
+bool pgSequence::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
+{
+    wxString sql = wxT("DROP SEQUENCE ") + GetQuotedFullIdentifier();
+    if (cascaded)
+        sql += wxT(" CASCADE");
+    return GetDatabase()->ExecuteVoid(sql);
 }
 
 
@@ -54,7 +64,7 @@ void pgSequence::UpdateValues()
 }
 
 
-wxString pgSequence::GetSql(wxTreeCtrl *browser)
+wxString pgSequence::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -69,7 +79,6 @@ wxString pgSequence::GetSql(wxTreeCtrl *browser)
             + wxT("\n  CACHE ") + GetCacheValue().ToString();
         if (GetCycled())
             sql += wxT("\n  CYCLE");
-
         sql += wxT(";\n")
             + GetOwnerSql(7, 3, wxT("TABLE ") + GetQuotedFullIdentifier())
             + GetGrant(wxT("arwdRxt"), wxT("TABLE ") + GetQuotedFullIdentifier())
@@ -79,7 +88,7 @@ wxString pgSequence::GetSql(wxTreeCtrl *browser)
     return sql;
 }
 
-void pgSequence::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgSequence::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     UpdateValues();
     if (properties)
@@ -125,22 +134,21 @@ void pgSequence::ShowStatistics(frmMain *form, ctlListView *statistics)
 }
 
 
-pgObject *pgSequence::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgSequence::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *sequence=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_SEQUENCES)
-            sequence = ReadObjects((pgCollection*)obj, 0, wxT("\n   AND cl.oid=") + GetOidStr());
-    }
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        sequence = sequenceFactory.CreateObjects(coll, 0, wxT("\n   AND cl.oid=") + GetOidStr());
+
     return sequence;
 }
 
 
+///////////////////////////////////////////////////////////////////////////////
 
-pgObject *pgSequence::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+
+pgObject *pgSequenceFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgSequence *sequence=0;
 
@@ -167,7 +175,7 @@ pgObject *pgSequence::ReadObjects(pgCollection *collection, wxTreeCtrl *browser,
 
             if (browser)
             {
-                collection->AppendBrowserItem(browser, sequence);
+                browser->AppendObject(collection, sequence);
 	  			sequences->MoveNext();
             }
             else
@@ -177,3 +185,17 @@ pgObject *pgSequence::ReadObjects(pgCollection *collection, wxTreeCtrl *browser,
     }
     return sequence;
 }
+
+
+#include "images/sequence.xpm"
+#include "images/sequences.xpm"
+
+pgSequenceFactory::pgSequenceFactory() 
+: pgSchemaObjFactory(__("Sequence"), __("New Sequence"), __("Create a new Sequence."), sequence_xpm)
+{
+    metaType = PGM_SEQUENCE;
+}
+
+
+pgSequenceFactory sequenceFactory;
+static pgaCollectionFactory cf(&sequenceFactory, __("Sequences"), sequences_xpm);
