@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTable.cpp 3965 2005-01-28 13:59:00Z andreas $
+// RCS-ID:      $Id: pgTable.cpp 4532 2005-10-12 14:14:25Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -9,25 +9,28 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
-// wxWindows headers
-#include <wx/wx.h>
 
-// App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
+#include "frmHint.h"
+#include "frmMain.h"
+#include "frmMaintenance.h"
 #include "pgTable.h"
-#include "pgCollection.h"
-#include "pgConstraints.h"
 #include "pgColumn.h"
 #include "pgIndexConstraint.h"
 #include "pgForeignKey.h"
 #include "pgCheck.h"
 #include "sysSettings.h"
 #include "pgfeatures.h"
+#include "pgRule.h"
+#include "pgTrigger.h"
+#include "pgConstraints.h"
+
+
+// App headers
 
 pgTable::pgTable(pgSchema *newSchema, const wxString& newName)
-: pgSchemaObject(newSchema, PG_TABLE, newName)
+: pgSchemaObject(newSchema, tableFactory, newName)
 {
     inheritedTableCount=0;
     rowsCounted = false;
@@ -38,82 +41,121 @@ pgTable::~pgTable()
 }
 
 
+int pgTable::GetIconId()
+{
+    if (isReplicated)
+        return tableFactory.GetReplicatedIconId();
+    else
+        return tableFactory.GetIconId();
+}
+
+
 wxMenu *pgTable::GetNewMenu()
 {
     wxMenu *menu=pgObject::GetNewMenu();
     if (schema->GetCreatePrivilege())
     {
-        AppendMenu(menu, PG_COLUMN);
+        columnFactory.AppendMenu(menu);
         if (GetPrimaryKey().IsEmpty())      // Will not notice if pk has been added after last refresh
-            AppendMenu(menu, PG_PRIMARYKEY);
-        AppendMenu(menu, PG_FOREIGNKEY);
-        AppendMenu(menu, PG_UNIQUE);
-        AppendMenu(menu, PG_CHECK);
-        AppendMenu(menu, PG_INDEX);
-        AppendMenu(menu, PG_RULE);
-        AppendMenu(menu, PG_TRIGGER);
+            primaryKeyFactory.AppendMenu(menu);
+        foreignKeyFactory.AppendMenu(menu);
+        uniqueFactory.AppendMenu(menu);
+        checkFactory.AppendMenu(menu);
+        indexFactory.AppendMenu(menu);
+        ruleFactory.AppendMenu(menu);
+        triggerFactory.AppendMenu(menu);
     }
     return menu;
 }
 
 
+int pgTable::GetReplicationStatus(ctlTree *browser, wxString *clusterName, long *setId)
+{
+    wxArrayString clusters=GetDatabase()->GetSlonyClusters(browser);
+
+    bool isSubscribed=false;
+
+    size_t i;
+    for (i=0 ; i < clusters.GetCount() ; i++)
+    {
+        wxString nsp=qtIdent(wxT("_") + clusters.Item(i));
+
+        pgSetIterator sets(GetConnection(),
+            wxT("SELECT tab_set, sub_provider, ") + nsp + wxT(".getlocalnodeid(") + qtString(wxT("_") + clusters.Item(i)) + wxT(") AS localnode\n")
+            wxT("  FROM ") + nsp + wxT(".sl_table\n")
+            wxT("  LEFT JOIN ") + nsp + wxT(".sl_subscribe ON sub_set=tab_set\n")
+            wxT(" WHERE tab_reloid = ") + GetOidStr());
+
+        if (sets.RowsLeft())
+        {
+            if (clusterName)
+                *clusterName = clusters.Item(i);
+            if (setId)
+                *setId = sets.GetLong(wxT("tab_set"));
+            if (isSubscribed)
+                return REPLICATIONSTATUS_MULTIPLY_PUBLISHED;
+
+            long provider=sets.GetLong(wxT("sub_provider"));
+            if (provider)
+            {
+                if (provider != sets.GetLong(wxT("localnode")))
+                    return REPLICATIONSTATUS_REPLICATED;
+
+                isSubscribed=true;
+
+            }
+        }
+    }
+    if (isSubscribed)
+        return REPLICATIONSTATUS_SUBSCRIBED;
+
+    return REPLICATIONSTATUS_NONE;
+}
+
+
 wxString pgTable::GetHelpPage(bool forCreate) const
 { 
     if (forCreate)
-        return wxT("sql-createtable");
+        return wxT("pg/sql-createtable");
     else
-        return wxT("sql-altertable");
+        return wxT("pg/sql-altertable");
 }
 
 
-bool pgTable::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgTable::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
-    return GetDatabase()->ExecuteVoid(wxT("DROP TABLE ") + GetQuotedFullIdentifier() + wxT(";"));
+    wxString sql = wxT("DROP TABLE ") + GetQuotedFullIdentifier();
+    if (cascaded)
+        sql += wxT(" CASCADE");
+    return GetDatabase()->ExecuteVoid(sql);
 }
 
 
-wxString pgTable::GetAllConstraints(wxTreeCtrl *browser, wxTreeItemId collectionId, int type)
+void pgTable::AppendStuff(wxString &sql, ctlTree *browser, pgaFactory &factory)
 {
-    wxString sql;
-    wxCookieType cookie;
-    pgObject *data;
-    wxTreeItemId item=browser->GetFirstChild(collectionId, cookie);
-            
-    while (item)
+    pgCollection *collection=browser->FindCollection(factory, GetId());
+    if (collection)
     {
-        data=(pgObject*)browser->GetItemData(item);
-        if (type < 0 || type == data->GetType())
-        {
-            sql += wxT(",\n  CONSTRAINT ") + data->GetQuotedIdentifier() 
-                + wxT(" ") + data->GetTypeName().Upper() 
-                + wxT(" ") ;
-            data->ShowTreeDetail(browser);
-            
-            switch (data->GetType())
-            {
-                case PG_PRIMARYKEY:
-                case PG_UNIQUE:
-                    sql += ((pgIndexConstraint*)data)->GetDefinition();
-                    break;
-                case PG_FOREIGNKEY:
-                    sql += ((pgForeignKey*)data)->GetDefinition();
-                    break;
-                case PG_CHECK:
-				  sql += wxT("(") + ((pgCheck*)data)->GetDefinition() + wxT(")");
-                    break;
-            }
-        }
-        
-        item=browser->GetNextChild(collectionId, cookie);
-    }
+		sql += wxT("\n");
+        collection->ShowTreeDetail(browser);
 
-    return sql;
+        treeObjectIterator idxIt(browser, collection);
+        pgObject *obj;
+        while ((obj = idxIt.GetNextObject()) != 0)
+        {
+            obj->ShowTreeDetail(browser);
+
+            sql += obj->GetSql(browser) + wxT("\n");
+        }
+    }
 }
 
 
-wxString pgTable::GetSql(wxTreeCtrl *browser)
+wxString pgTable::GetSql(ctlTree *browser)
 {
 	wxString colDetails;
+    wxString prevComment;
+
     if (sql.IsNull())
     {
         // make sure all kids are appended
@@ -122,75 +164,85 @@ wxString pgTable::GetSql(wxTreeCtrl *browser)
             + wxT("-- DROP TABLE ") + GetQuotedFullIdentifier() + wxT(";")
             + wxT("\n\nCREATE TABLE ") + GetQuotedFullIdentifier() + wxT("\n(\n");
 
-        pgObject *data;
-        wxCookieType cookie;
-        wxTreeItemId item=browser->GetFirstChild(GetId(), cookie);
-        wxTreeItemId columnsItem, constraintsItem;
-        while (item)
+        pgCollection *columns=browser->FindCollection(columnFactory, GetId());
+        if (columns)
         {
-            data=(pgObject*)browser->GetItemData(item);
-            if (data->GetType() == PG_COLUMNS)
-                columnsItem = item;
-            else if (data->GetType() == PG_CONSTRAINTS)
-                constraintsItem = item;
+            columns->ShowTreeDetail(browser);
+            treeObjectIterator colIt(browser, columns);
 
-            if (columnsItem && constraintsItem)
-                break;
-
-            item=browser->GetNextChild(GetId(), cookie);
-        }
-        if (columnsItem)
-        {
-            pgCollection *coll=(pgCollection*)browser->GetItemData(columnsItem);
-            // make sure all columns are appended
-            coll->ShowTreeDetail(browser);
-            // this is the columns collection
-            wxTreeItemId item=browser->GetFirstChild(columnsItem, cookie); 
-
-            // add columns
             int colCount=0;
-            while (item)
+            pgColumn *column;
+            while ((column = (pgColumn*)colIt.GetNextObject()) != 0)
             {
-                data=(pgObject*)browser->GetItemData(item);
-                if (data->GetType() == PG_COLUMN)
+                column->ShowTreeDetail(browser);
+                if (column->GetColNumber() > 0)
                 {
-                    pgColumn *column=(pgColumn*)data;
-                    // make sure column details are read
-                    column->ShowTreeDetail(browser);
-
-                    if (column->GetColNumber() > 0)
+                    if (colCount)
                     {
-                        if (colCount)
-                            sql += wxT(",\n");
+                        sql += wxT(",");
+                        if (!prevComment.IsEmpty())
+                            sql += wxT(" -- ") + prevComment.BeforeFirst('\n');
 
-                        sql += wxT("  ") + column->GetQuotedIdentifier() + wxT(" ")
-                            + column->GetDefinition();
-
-						// Whilst we are looping round the columns, grab their comments as well.
-						// Perhaps we should also get storage types here?
-						colDetails += column->GetCommentSql();
-						if (colDetails.Length() > 0)
-							if (colDetails.Last() != '\n') colDetails += wxT("\n");
-
-                        colCount++;
+                        sql += wxT("\n");
                     }
+
+                    sql += wxT("  ") + column->GetQuotedIdentifier() + wxT(" ")
+                        + column->GetDefinition();
+
+                    prevComment = column->GetComment();
+
+					// Whilst we are looping round the columns, grab their comments as well.
+					// Perhaps we should also get storage types here?
+					colDetails += column->GetCommentSql();
+					if (colDetails.Length() > 0)
+						if (colDetails.Last() != '\n') colDetails += wxT("\n");
+
+                    colCount++;
                 }
-                
-                item=browser->GetNextChild(columnsItem, cookie);
             }
         }
 
-        if (constraintsItem)
+        pgCollection *constraints=browser->FindCollection(primaryKeyFactory, GetId());
+        if (constraints)
         {
-            pgCollection *coll=(pgCollection*)browser->GetItemData(constraintsItem);
-            // make sure all kids are read
-            coll->ShowTreeDetail(browser);
+            constraints->ShowTreeDetail(browser);
+            treeObjectIterator consIt(browser, constraints);
 
-            sql += GetAllConstraints(browser, constraintsItem, PG_PRIMARYKEY);
-            sql += GetAllConstraints(browser, constraintsItem, PG_FOREIGNKEY);
-            sql += GetAllConstraints(browser, constraintsItem, PG_UNIQUE);
-            sql += GetAllConstraints(browser, constraintsItem, PG_CHECK);
+            pgObject *data;
+            
+            while ((data=consIt.GetNextObject()) != 0)
+            {
+                data->ShowTreeDetail(browser);
+
+                sql += wxT(",");
+
+                if (!prevComment.IsEmpty())
+                    sql += wxT(" -- ") + prevComment.BeforeFirst('\n');
+
+                sql += wxT("\n  CONSTRAINT ") + data->GetQuotedIdentifier() 
+                    + wxT(" ") + data->GetTypeName().Upper() 
+                    + wxT(" ") ;
+
+                prevComment = data->GetComment();
+            
+                switch (data->GetMetaType())
+                {
+                    case PGM_PRIMARYKEY:
+                    case PGM_UNIQUE:
+                        sql += ((pgIndexConstraint*)data)->GetDefinition();
+                        break;
+                    case PGM_FOREIGNKEY:
+                        sql += ((pgForeignKey*)data)->GetDefinition();
+                        break;
+                    case PGM_CHECK:
+				      sql += wxT("(") + ((pgCheck*)data)->GetDefinition() + wxT(")");
+                        break;
+                }
+            }
         }
+        if (!prevComment.IsEmpty())
+            sql += wxT(" -- ") + prevComment.BeforeFirst('\n');
+
         sql += wxT("\n) ");
         if (GetInheritedTableCount())
         {
@@ -210,21 +262,17 @@ wxString pgTable::GetSql(wxTreeCtrl *browser)
             + GetCommentSql();
 
 		// Column comments
-		sql += colDetails;
-
-        // add indexes here
-
-        // add triggers here 
-
-		if (sql.Length() > 0)
-			if (sql.Last() != '\n') sql += wxT("\n");
+		sql += colDetails + wxT("\n");
 
+        AppendStuff(sql, browser, indexFactory);
+        AppendStuff(sql, browser, ruleFactory);
+        AppendStuff(sql, browser, triggerFactory);
     }
     return sql;
 }
 
 
-wxString pgTable::GetCoveringIndex(wxTreeCtrl *browser, const wxString &collist)
+wxString pgTable::GetCoveringIndex(ctlTree *browser, const wxString &collist)
 {
     // delivers the name of the index which covers the named columns
     wxCookieType cookie;
@@ -232,15 +280,15 @@ wxString pgTable::GetCoveringIndex(wxTreeCtrl *browser, const wxString &collist)
     wxTreeItemId collItem=browser->GetFirstChild(GetId(), cookie);
     while (collItem)
     {
-        pgObject *data=(pgObject*)browser->GetItemData(collItem);
-        if (data && (data->GetType() == PG_CONSTRAINTS || data->GetType() == PG_INDEXES))
+        pgObject *data=browser->GetObject(collItem);
+        if (data && data->IsCollection() && (data->GetMetaType() == PGM_CONSTRAINT || data->GetMetaType() == PGM_INDEX))
         {
             wxCookieType cookie2;
             wxTreeItemId item=browser->GetFirstChild(collItem, cookie2);
             while (item)
             {
-                pgIndex *index=(pgIndex*)browser->GetItemData(item);
-                if (index && (index->GetType() == PG_INDEX || index->GetType() == PG_PRIMARYKEY || index->GetType() == PG_UNIQUE))
+                pgIndex *index=(pgIndex*)browser->GetObject(item);
+                if (index && (index->GetMetaType() == PGM_INDEX || index->GetMetaType() == PGM_PRIMARYKEY || index->GetMetaType() == PGM_UNIQUE))
                 {
                     index->ShowTreeDetail(browser);
                     if (collist == index->GetColumns() || 
@@ -305,43 +353,23 @@ void pgTable::UpdateInheritance()
 
 
 
-void pgTable::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgTable::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (!expandedKids)
     {
         expandedKids=true;
 
-        RemoveDummyChild(browser);
+        browser->RemoveDummyChild(this);
 
         // Log
         wxLogInfo(wxT("Adding child object to table ") + GetIdentifier());
 
-        pgCollection *collection;
 
-        // Columns
-        collection = new pgCollection(PG_COLUMNS, GetSchema());
-        collection->iSetOid(GetOid());
-        AppendBrowserItem(browser, collection);
-
-        // Constraints
-        collection = new pgConstraints(GetSchema());
-        collection->iSetOid(GetOid());
-        AppendBrowserItem(browser, collection);
-
-        // Indexes
-        collection = new pgCollection(PG_INDEXES, GetSchema());
-        collection->iSetOid(GetOid());
-        AppendBrowserItem(browser, collection);
-
-        // Rules
-        collection = new pgCollection(PG_RULES, GetSchema());
-        collection->iSetOid(GetOid());
-        AppendBrowserItem(browser, collection);
-
-        // Triggers
-        collection = new pgCollection(PG_TRIGGERS, GetSchema());
-        collection->iSetOid(GetOid());
-        AppendBrowserItem(browser, collection);
+        browser->AppendCollection(this, columnFactory);
+        browser->AppendCollection(this, constraintFactory);
+        browser->AppendCollection(this, indexFactory);
+        browser->AppendCollection(this, ruleFactory);
+        browser->AppendCollection(this, triggerFactory);
 
         // convert list of columns numbers to column names
         wxStringTokenizer collist(GetPrimaryKeyColNumbers(), wxT(","));
@@ -395,6 +423,32 @@ void pgTable::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *pr
         else
             properties->AppendItem(_("Rows (counted)"), _("not counted"));
 
+        long setId;
+        wxString clusterName;
+        long repStat=GetReplicationStatus(browser, &clusterName, &setId);
+
+        wxString clusterInfo;
+        clusterInfo.Printf(_("Cluster \"%s\", set %ld"), clusterName.c_str(), setId);
+
+        wxString repString;
+        switch (repStat)
+        {
+            case REPLICATIONSTATUS_SUBSCRIBED:
+                repString = _("Published");
+                break;
+            case REPLICATIONSTATUS_REPLICATED:
+                repString = _("Replicated");
+                break;
+            case REPLICATIONSTATUS_MULTIPLY_PUBLISHED:
+                repString = _("Replicated");
+                clusterName = _("Multiple clusters");
+                break;
+            default:
+                break;
+        }
+        if (!repString.IsEmpty())
+            properties->AppendItem(repString, clusterInfo);
+
         properties->AppendItem(_("Inherits tables"), GetHasSubclass());
         properties->AppendItem(_("Inherited tables count"), GetInheritedTableCount());
         if (GetInheritedTableCount())
@@ -402,10 +456,143 @@ void pgTable::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *pr
         properties->AppendItem(_("Has OIDs?"), GetHasOids());
         properties->AppendItem(_("System table?"), GetSystemObject());
         properties->AppendItem(_("Comment"), GetComment());
+
+    }
+    if (form && GetVacuumHint() && !hintShown)
+    {
+        ShowHint(form, false);
     }
 }
 
 
+bool pgTable::GetCanHint()
+{
+    return (GetVacuumHint() || primaryKey.IsEmpty());
+}
+
+
+bool pgTable::GetVacuumHint()
+{
+    bool canHint=false;
+
+    if (rowsCounted)
+    {
+        if (!estimatedRows || (estimatedRows == 1000 && rows.GetValue() != 1000))
+            canHint = (rows >= 20);
+        else
+        {
+            double rowsDbl=(wxLongLong_t)rows.GetValue();
+            double quot=rowsDbl *10. / estimatedRows;
+            canHint = ((quot > 12 || quot < 8) && (rowsDbl < estimatedRows-20. || rowsDbl > estimatedRows+20.));
+        }
+    }
+    else if (estimatedRows == 1000)
+    {
+        canHint = true;
+    }
+    return canHint;
+}
+
+
+void pgTable::ShowHint(frmMain *form, bool force)
+{
+    hintShown = true;
+    int rc;
+    
+    if (force)
+    {
+        wxArrayString hints;
+        if (GetVacuumHint())
+            hints.Add(HINT_VACUUM);
+        if (primaryKey.IsEmpty())
+            hints.Add(HINT_PRIMARYKEY);
+
+        rc=frmHint::ShowHint(form, hints, GetFullIdentifier(), force);
+    }
+    else
+        rc=frmHint::ShowHint(form, HINT_VACUUM, GetFullIdentifier(), force);
+
+    if (rc == HINT_RC_FIX)
+    {
+        frmMaintenance *frm=new frmMaintenance(form, this);
+        frm->Go();
+    }
+}
+
+
+
+
+pgObject *pgTable::Refresh(ctlTree *browser, const wxTreeItemId item)
+{
+    pgTable *table=0;
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        table = (pgTable*)tableFactory.CreateObjects(coll, 0, wxT("\n   AND rel.oid=") + GetOidStr());
+
+    return table;
+}
+
+
+///////////////////////////////////////////////////////////
+
+
+pgTableCollection::pgTableCollection(pgaFactory *factory, pgSchema *sch)
+: pgSchemaObjCollection(factory, sch)
+{
+}
+
+    
+void pgTableCollection::ShowStatistics(frmMain *form, ctlListView *statistics)
+{
+    wxLogInfo(wxT("Displaying statistics for tables on ")+ GetSchema()->GetIdentifier());
+
+    bool hasSize=GetConnection()->HasFeature(FEATURE_SIZE);
+
+    // Add the statistics view columns
+    statistics->ClearAll();
+    statistics->AddColumn(_("Table"), 100);
+    statistics->AddColumn(_("Tuples inserted"), 50);
+    statistics->AddColumn(_("Tuples updated"), 50);
+    statistics->AddColumn(_("Tuples deleted"), 50);
+    if (hasSize)
+        statistics->AddColumn(_("Size"), 60);
+
+    wxString sql=wxT("SELECT st.relname, n_tup_ins, n_tup_upd, n_tup_del");
+    if (hasSize)
+        sql += wxT(", pg_size_pretty(pg_relation_size(st.relid)")
+               wxT(" + CASE WHEN cl.reltoastrelid = 0 THEN 0 ELSE pg_relation_size(cl.reltoastrelid) + COALESCE((SELECT SUM(pg_relation_size(indexrelid)) FROM pg_index WHERE indrelid=cl.reltoastrelid)::int8, 0) END")
+               wxT(" + COALESCE((SELECT SUM(pg_relation_size(indexrelid)) FROM pg_index WHERE indrelid=st.relid)::int8, 0)) AS size");
+    
+    sql += wxT("\n  FROM pg_stat_all_tables st")
+           wxT("  JOIN pg_class cl on cl.oid=st.relid\n")
+	       wxT(" WHERE schemaname = ") + qtString(GetSchema()->GetName())
+	    +  wxT("\n ORDER BY relname");
+
+    pgSet *stats = GetDatabase()->ExecuteSet(sql);
+
+    if (stats)
+    {
+        long pos=0;
+        while (!stats->Eof())
+        {
+            statistics->InsertItem(pos, stats->GetVal(wxT("relname")), PGICON_STATISTICS);
+            statistics->SetItem(pos, 1, stats->GetVal(wxT("n_tup_ins")));
+            statistics->SetItem(pos, 2, stats->GetVal(wxT("n_tup_upd")));
+            statistics->SetItem(pos, 3, stats->GetVal(wxT("n_tup_del")));
+            if (hasSize)
+                statistics->SetItem(pos, 4, stats->GetVal(wxT("size")));
+            stats->MoveNext();
+            pos++;
+        }
+
+	    delete stats;
+    }
+}
+
+
+///////////////////////////////////////////////////////////
+
+
 void pgTable::ShowStatistics(frmMain *form, ctlListView *statistics)
 {
     wxString sql =
@@ -428,7 +615,7 @@ void pgTable::ShowStatistics(frmMain *form, ctlListView *statistics)
     if (GetConnection()->HasFeature(FEATURE_SIZE))
     {
         sql += wxT(", pg_size_pretty(pg_relation_size(stat.relid)) AS ") + qtIdent(_("Table Size"))
-            +  wxT(", CASE WHEN cl.reltoastrelid = 0 THEN ") + qtString(_("none")) + wxT(" ELSE pg_size_pretty(pg_relation_size(cl.reltoastrelid)) END AS ") + qtIdent(_("Toast Table Size"))
+            +  wxT(", CASE WHEN cl.reltoastrelid = 0 THEN ") + qtString(_("none")) + wxT(" ELSE pg_size_pretty(pg_relation_size(cl.reltoastrelid)+ COALESCE((SELECT SUM(pg_relation_size(indexrelid)) FROM pg_index WHERE indrelid=cl.reltoastrelid)::int8, 0)) END AS ") + qtIdent(_("Toast Table Size"))
             +  wxT(", pg_size_pretty(COALESCE((SELECT SUM(pg_relation_size(indexrelid)) FROM pg_index WHERE indrelid=stat.relid)::int8, 0)) AS ") + qtIdent(_("Indexes Size"));
     }
     sql +=  wxT("\n")
@@ -441,32 +628,20 @@ void pgTable::ShowStatistics(frmMain *form, ctlListView *statistics)
 }
 
 
-
-pgObject *pgTable::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
-{
-    pgTable *table=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_TABLES)
-            table = (pgTable*)ReadObjects((pgCollection*)obj, 0, wxT("\n   AND rel.oid=") + GetOidStr());
-    }
-    return table;
-}
-
-
-
-pgObject *pgTable::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+pgObject *pgTableFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgTable *table=0;
 
     pgSet *tables;
-    if (collection->GetConnection()->BackendMinimumVersion(7, 5))
+    if (collection->GetConnection()->BackendMinimumVersion(8, 0))
     {
         tables= collection->GetDatabase()->ExecuteSet(
             wxT("SELECT rel.oid, relname, spcname, pg_get_userbyid(relowner) AS relowner, relacl, relhasoids, ")
-                    wxT("relhassubclass, reltuples, description, conname, conkey\n")
+                    wxT("relhassubclass, reltuples, description, conname, conkey,\n")
+            wxT("       EXISTS(select 1 FROM pg_trigger\n")
+            wxT("                       JOIN pg_proc pt ON pt.oid=tgfoid AND pt.proname='logtrigger'\n")
+            wxT("                       JOIN pg_proc pc ON pc.pronamespace=pt.pronamespace AND pc.proname='slonyversion'\n")
+            wxT("                     WHERE tgrelid=rel.oid) AS isrepl\n")
             wxT("  FROM pg_class rel\n")
             wxT("  LEFT OUTER JOIN pg_tablespace ta on ta.oid=rel.reltablespace\n")
             wxT("  LEFT OUTER JOIN pg_description des ON des.objoid=rel.oid AND des.objsubid=0\n")
@@ -479,7 +654,11 @@ pgObject *pgTable::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, co
     {
         tables= collection->GetDatabase()->ExecuteSet(
             wxT("SELECT rel.oid, relname, pg_get_userbyid(relowner) AS relowner, relacl, relhasoids, ")
-                    wxT("relhassubclass, reltuples, description, conname, conkey\n")
+                    wxT("relhassubclass, reltuples, description, conname, conkey,\n")
+            wxT("       EXISTS(select 1 FROM pg_trigger\n")
+            wxT("                       JOIN pg_proc pt ON pt.oid=tgfoid AND pt.proname='logtrigger'\n")
+            wxT("                       JOIN pg_proc pc ON pc.pronamespace=pt.pronamespace AND pc.proname='slonyversion'\n")
+            wxT("                     WHERE tgrelid=rel.oid) AS isrepl\n")
             wxT("  FROM pg_class rel\n")
             wxT("  LEFT OUTER JOIN pg_description des ON des.objoid=rel.oid AND des.objsubid=0\n")
             wxT("  LEFT OUTER JOIN pg_constraint c ON c.conrelid=rel.oid AND c.contype='p'\n")
@@ -503,13 +682,14 @@ pgObject *pgTable::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, co
             table->iSetEstimatedRows(tables->GetDouble(wxT("reltuples")));
             table->iSetHasSubclass(tables->GetBool(wxT("relhassubclass")));
             table->iSetPrimaryKeyName(tables->GetVal(wxT("conname")));
+            table->iSetIsReplicated(tables->GetBool(wxT("isrepl")));
             wxString cn=tables->GetVal(wxT("conkey"));
             cn=cn.Mid(1, cn.Length()-2);
             table->iSetPrimaryKeyColNumbers(cn);
 
             if (browser)
             {
-                collection->AppendBrowserItem(browser, table);
+                browser->AppendObject(collection, table);
                 tables->MoveNext();
             }
             else
@@ -522,50 +702,32 @@ pgObject *pgTable::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, co
 }
 
 
-void pgTable::ShowStatistics(pgCollection *collection, ctlListView *statistics)
+#include "images/table.xpm"
+#include "images/table-repl.xpm"
+#include "images/table-repl-sm.xpm"
+#include "images/table-sm.xpm"
+#include "images/tables.xpm"
+
+pgTableFactory::pgTableFactory() 
+: pgSchemaObjFactory(__("Table"), __("New Table"), __("Create a new Table."), table_xpm, table_sm_xpm)
 {
-    wxLogInfo(wxT("Displaying statistics for tables on ")+ collection->GetSchema()->GetIdentifier());
-
-    bool hasSize=collection->GetConnection()->HasFeature(FEATURE_SIZE);
-
-    // Add the statistics view columns
-    statistics->ClearAll();
-    statistics->AddColumn(_("Table"), 100);
-    statistics->AddColumn(_("Tuples inserted"), 50);
-    statistics->AddColumn(_("Tuples updated"), 50);
-    statistics->AddColumn(_("Tuples deleted"), 50);
-    if (hasSize)
-        statistics->AddColumn(_("Size"), 60);
-
-    wxString sql=wxT("SELECT st.relname, n_tup_ins, n_tup_upd, n_tup_del");
-    if (hasSize)
-        sql += wxT(", pg_size_pretty(pg_relation_size(st.relid)")
-               wxT(" + CASE WHEN cl.reltoastrelid = 0 THEN 0 ELSE pg_relation_size(cl.reltoastrelid) END")
-               wxT(" + COALESCE((SELECT SUM(pg_relation_size(indexrelid)) FROM pg_index WHERE indrelid=st.relid)::int8, 0)) AS size");
-    
-    sql += wxT("\n  FROM pg_stat_all_tables st")
-           wxT("  JOIN pg_class cl on cl.oid=st.relid\n")
-	       wxT(" WHERE schemaname = ") + qtString(collection->GetSchema()->GetName())
-	    +  wxT("\n ORDER BY relname");
-
-    pgSet *stats = collection->GetDatabase()->ExecuteSet(sql);
-
-    if (stats)
-    {
-        long pos=0;
-        while (!stats->Eof())
-        {
-            statistics->InsertItem(pos, stats->GetVal(wxT("relname")), PGICON_STATISTICS);
-            statistics->SetItem(pos, 1, stats->GetVal(wxT("n_tup_ins")));
-            statistics->SetItem(pos, 2, stats->GetVal(wxT("n_tup_upd")));
-            statistics->SetItem(pos, 3, stats->GetVal(wxT("n_tup_del")));
-            if (hasSize)
-                statistics->SetItem(pos, 4, stats->GetVal(wxT("size")));
-            stats->MoveNext();
-            pos++;
-        }
-
-	    delete stats;
-    }
+    metaType = PGM_TABLE;
+    if (WantSmallIcon())
+        replicatedIconId = addIcon(table_repl_sm_xpm);
+    else
+        replicatedIconId = addIcon(table_repl_xpm);
 }
 
+pgCollection *pgTableFactory::CreateCollection(pgObject *obj)
+{
+    return new pgTableCollection(GetCollectionFactory(), (pgSchema*)obj);
+}
+
+pgTableFactory tableFactory;
+static pgaCollectionFactory cf(&tableFactory, __("Tables"), tables_xpm);
+
+
+pgCollection *pgTableObjFactory::CreateCollection(pgObject *obj)
+{
+    return new pgTableObjCollection(GetCollectionFactory(), (pgTable*)obj);
+}
