@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTablespace.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgTablespace.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -17,14 +17,13 @@
 #include "pgAdmin3.h"
 #include "misc.h"
 #include "pgfeatures.h"
-#include "pgObject.h"
 #include "pgTablespace.h"
-#include "pgCollection.h"
+#include "pgDatabase.h"
 #include "frmMain.h"
 
 
 pgTablespace::pgTablespace(const wxString& newName)
-: pgServerObject(PG_TABLESPACE, newName)
+: pgServerObject(tablespaceFactory, newName)
 {
     wxLogInfo(wxT("Creating a pgTablespace object"));
 }
@@ -60,7 +59,7 @@ void pgTablespace::ShowReferencedBy(frmMain *form, ctlListView *referencedBy, co
                 dblist.Add(datname);
             OID oid=set->GetOid(wxT("dattablespace"));
             if (oid == GetOid())
-                referencedBy->AppendItem(PGICON_DATABASE, _("Database"), datname);
+                referencedBy->AppendItem(databaseFactory.GetIconId(), _("Database"), datname);
 
             set->MoveNext();
         }
@@ -80,17 +79,17 @@ void pgTablespace::ShowReferencedBy(frmMain *form, ctlListView *referencedBy, co
         wxT("        OR (cl.reltablespace=0 AND dattablespace = ") + GetOidStr() + wxT("))\n")
         wxT(" ORDER BY 1,2,3"));
 
-    form->EndMsg();
+    form->EndMsg(set != 0);
 }
 
 
-bool pgTablespace::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgTablespace::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
     return GetConnection()->ExecuteVoid(wxT("DROP TABLESPACE ") + GetQuotedFullIdentifier() + wxT(";"));
 }
 
 
-wxString pgTablespace::GetSql(wxTreeCtrl *browser)
+wxString pgTablespace::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -108,7 +107,7 @@ wxString pgTablespace::GetSql(wxTreeCtrl *browser)
 }
 
 
-void pgTablespace::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgTablespace::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (!expandedKids)
     {
@@ -159,22 +158,19 @@ void pgTablespace::ShowStatistics(frmMain *form, ctlListView *statistics)
 }
 
 
-pgObject *pgTablespace::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgTablespace::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *tablespace=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_TABLESPACES)
-            tablespace = ReadObjects((pgCollection*)obj, 0, wxT("\n WHERE ts.oid=") + GetOidStr());
-    }
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        tablespace = tablespaceFactory.CreateObjects(coll, 0, wxT("\n WHERE ts.oid=") + GetOidStr());
+
     return tablespace;
 }
 
 
 
-pgObject *pgTablespace::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+pgObject *pgTablespaceFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgTablespace *tablespace=0;
 
@@ -200,7 +196,7 @@ pgObject *pgTablespace::ReadObjects(pgCollection *collection, wxTreeCtrl *browse
 
             if (browser)
             {
-                collection->AppendBrowserItem(browser, tablespace);
+                browser->AppendObject(collection, tablespace);
 				tablespaces->MoveNext();
             }
             else
@@ -213,9 +209,15 @@ pgObject *pgTablespace::ReadObjects(pgCollection *collection, wxTreeCtrl *browse
 }
 
 
-void pgTablespace::ShowStatistics(pgCollection *collection, ctlListView *statistics)
+pgTablespaceCollection::pgTablespaceCollection(pgaFactory *factory, pgServer *sv)
+: pgServerObjCollection(factory, sv)
+{ 
+}
+
+
+void pgTablespaceCollection::ShowStatistics(frmMain *form, ctlListView *statistics)
 {
-    if (collection->GetConnection()->HasFeature(FEATURE_SIZE))
+    if (GetConnection()->HasFeature(FEATURE_SIZE))
     {
         wxLogInfo(wxT("Displaying statistics for tablespaces"));
 
@@ -224,7 +226,7 @@ void pgTablespace::ShowStatistics(pgCollection *collection, ctlListView *statist
         statistics->AddColumn(_("Tablespace"), 100);
         statistics->AddColumn(_("Size"), 60);
 
-        pgSet *stats = collection->GetConnection()->ExecuteSet(
+        pgSet *stats = GetConnection()->ExecuteSet(
             wxT("SELECT spcname, pg_size_pretty(pg_tablespace_size(oid)) AS size FROM pg_tablespace ORDER BY spcname"));
 
         if (stats)
@@ -243,3 +245,22 @@ void pgTablespace::ShowStatistics(pgCollection *collection, ctlListView *statist
     }
 }
 
+
+
+#include "images/tablespace.xpm"
+#include "images/tablespaces.xpm"
+
+
+pgTablespaceFactory::pgTablespaceFactory() 
+: pgServerObjFactory(__("Tablespace"), __("New Tablespace"), __("Create a new Tablespace."), tablespace_xpm)
+{
+}
+
+
+pgCollection *pgTablespaceFactory::CreateCollection(pgObject *obj)
+{
+    return new pgTablespaceCollection(GetCollectionFactory(), (pgServer*)obj);
+}
+
+pgTablespaceFactory tablespaceFactory;
+static pgaCollectionFactory cf(&tablespaceFactory, __("Tablespaces"), tablespaces_xpm);
