@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgType.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgType.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,14 +15,12 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgType.h"
-#include "pgCollection.h"
 #include "pgDatatype.h"
 
 
 pgType::pgType(pgSchema *newSchema, const wxString& newName)
-: pgSchemaObject(newSchema, PG_TYPE, newName)
+: pgSchemaObject(newSchema, typeFactory, newName)
 {
 }
 
@@ -30,12 +28,15 @@ pgType::~pgType()
 {
 }
 
-bool pgType::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgType::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
-    return GetDatabase()->ExecuteVoid(wxT("DROP TYPE ") + GetQuotedFullIdentifier() + wxT(";"));
+    wxString sql = wxT("DROP TYPE ") + GetQuotedFullIdentifier();
+    if (cascaded)
+        sql += wxT(" CASCADE");
+    return GetDatabase()->ExecuteVoid(sql);
 }
 
-wxString pgType::GetSql(wxTreeCtrl *browser)
+wxString pgType::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -71,7 +72,7 @@ wxString pgType::GetSql(wxTreeCtrl *browser)
 
 
 
-void pgType::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgType::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (!expandedKids)
     {
@@ -157,22 +158,21 @@ void pgType::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *pro
 
 
 
-pgObject *pgType::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgType::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *type=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_TYPES)
-            type = ReadObjects((pgCollection*)obj, 0, wxT("\n   AND t.oid=") + GetOidStr());
-    }
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        type = typeFactory.CreateObjects(coll, 0, wxT("\n   AND t.oid=") + GetOidStr());
+
     return type;
 }
 
 
+/////////////////////////////////////////////////////////
 
-pgObject *pgType::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+
+pgObject *pgTypeFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgType *type=0;
     wxString systemRestriction;
@@ -227,7 +227,7 @@ pgObject *pgType::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, con
 
             if (browser)
             {
-                collection->AppendBrowserItem(browser, type);
+                browser->AppendObject(collection, type);
     			types->MoveNext();
             }
             else
@@ -238,3 +238,16 @@ pgObject *pgType::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, con
     }
     return type;
 }
+
+
+#include "images/type.xpm"
+#include "images/types.xpm"
+
+pgTypeFactory::pgTypeFactory() 
+: pgSchemaObjFactory(__("Type"), __("New Type"), __("Create a new Type."), type_xpm)
+{
+}
+
+
+pgTypeFactory typeFactory;
+static pgaCollectionFactory cf(&typeFactory, __("Types"), types_xpm);
