@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgView.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: pgView.cpp 4478 2005-10-03 00:19:51Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -15,13 +15,11 @@
 // App headers
 #include "pgAdmin3.h"
 #include "misc.h"
-#include "pgObject.h"
 #include "pgView.h"
-#include "pgCollection.h"
 
 
 pgView::pgView(pgSchema *newSchema, const wxString& newName)
-: pgRuleObject(newSchema, PG_VIEW, newName)
+: pgRuleObject(newSchema, viewFactory, newName)
 {
 }
 
@@ -34,17 +32,21 @@ wxMenu *pgView::GetNewMenu()
 {
     wxMenu *menu=pgObject::GetNewMenu();
     if (schema->GetCreatePrivilege())
-        AppendMenu(menu, PG_RULE);
+        ruleFactory.AppendMenu(menu);
+
     return menu;
 }
 
 
-bool pgView::DropObject(wxFrame *frame, wxTreeCtrl *browser)
+bool pgView::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
 {
-    return GetDatabase()->ExecuteVoid(wxT("DROP VIEW ") + GetQuotedFullIdentifier() + wxT(";"));
+    wxString sql = wxT("DROP VIEW ") + GetQuotedFullIdentifier();
+    if (cascaded)
+        sql += wxT(" CASCADE");
+    return GetDatabase()->ExecuteVoid(sql);
 }
 
-wxString pgView::GetSql(wxTreeCtrl *browser)
+wxString pgView::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
@@ -61,18 +63,15 @@ wxString pgView::GetSql(wxTreeCtrl *browser)
 }
 
 
-void pgView::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
+void pgView::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *properties, ctlSQLBox *sqlPane)
 {
     if (!expandedKids)
     {
         expandedKids = true;
-
-        RemoveDummyChild(browser);
-
-        pgCollection *collection;
-        collection = new pgCollection(PG_RULES, GetSchema());
+        browser->RemoveDummyChild(this);
+        
+        pgCollection *collection = browser->AppendCollection(this, ruleFactory);
         collection->iSetOid(GetOid());
-        AppendBrowserItem(browser, collection);
     }
     if (properties)
     {
@@ -92,22 +91,21 @@ void pgView::ShowTreeDetail(wxTreeCtrl *browser, frmMain *form, ctlListView *pro
 
 
 
-pgObject *pgView::Refresh(wxTreeCtrl *browser, const wxTreeItemId item)
+pgObject *pgView::Refresh(ctlTree *browser, const wxTreeItemId item)
 {
     pgObject *view=0;
-    wxTreeItemId parentItem=browser->GetItemParent(item);
-    if (parentItem)
-    {
-        pgObject *obj=(pgObject*)browser->GetItemData(parentItem);
-        if (obj->GetType() == PG_VIEWS)
-            view = ReadObjects((pgCollection*)obj, 0, wxT("\n   AND c.oid=") + GetOidStr());
-    }
+    pgCollection *coll=browser->GetParentCollection(item);
+    if (coll)
+        view = viewFactory.CreateObjects(coll, 0, wxT("\n   AND c.oid=") + GetOidStr());
+
     return view;
 }
 
 
+///////////////////////////////////////////////////////
 
-pgObject *pgView::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, const wxString &restriction)
+
+pgObject *pgViewFactory::CreateObjects(pgCollection *collection, ctlTree *browser, const wxString &restriction)
 {
     pgView *view=0;
 
@@ -150,3 +148,18 @@ pgObject *pgView::ReadObjects(pgCollection *collection, wxTreeCtrl *browser, con
     }
     return view;
 }
+
+
+#include "images/view.xpm"
+#include "images/view-sm.xpm"
+#include "images/views.xpm"
+
+pgViewFactory::pgViewFactory() 
+: pgSchemaObjFactory(__("View"), __("New View"), __("Create a new View."), view_xpm, view_sm_xpm)
+{
+    metaType = PGM_VIEW;
+}
+
+
+pgViewFactory viewFactory;
+static pgaCollectionFactory cf(&viewFactory, __("Views"), views_xpm);
