@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: misc.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: misc.cpp 4486 2005-10-04 17:36:23Z andreas $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -33,7 +33,6 @@
 
 // App headers
 #include "misc.h"
-#include "menu.h"
 #include "frmMain.h"
 #include "frmHelp.h"
 
@@ -46,190 +45,11 @@ extern "C"
 #include "parser/parse.h"
 }
 
-// we dont have an appropriate wxLongLong method
-#ifdef __WIN32__
-#define atolonglong _atoi64
-#else
-#ifdef __WXMAC__
-#define atolonglong(str) strtoll(str, (char **)NULL, 10) 
-#else
-#ifdef __FreeBSD__
-#define atolonglong(str) strtoll(str, (char **)NULL, 10)
-#else
-#define atolonglong atoll
-#endif
-#endif
-#endif
-
-
-
-// Conversions
-
-
-wxString BoolToYesNo(bool value)
+wxString IdAndName(long id, const wxString &name)
 {
-    return value ? _("Yes") : _("No");
-}
-
-
-wxString BoolToStr(bool value)
-{
-    return value ? wxT("true") : wxT("false");
-}
-
-
-
-bool StrToBool(const wxString& value)
-{
-    if (value.StartsWith(wxT("t"))) {
-        return TRUE;
-    } else if (value.StartsWith(wxT("T"))) {
-        return TRUE;
-    } else if (value.StartsWith(wxT("1"))) {
-        return TRUE;
-    } else if (value.StartsWith(wxT("Y"))) {
-        return TRUE;
-    } else if (value.StartsWith(wxT("y"))) {
-        return TRUE;
-    } 
-
-    return FALSE;
-}
-
-wxString NumToStr(long value)
-{
-    wxString result;
-    result.Printf(wxT("%ld"), value);
-    return result;
-}
-
-
-wxString NumToStr(OID value)
-{
-    wxString result;
-    result.Printf(wxT("%lu"), (long)value);
-    return result;
-}
-
-
-long StrToLong(const wxString& value)
-{
-    return atol(value.ToAscii());
-}
-
-
-OID StrToOid(const wxString& value)
-{
-    return (OID)strtoul(value.ToAscii(), 0, 10);
-}
-
-
-wxString NumToStr(double value)
-{
-    wxString result;
-    static wxString decsep;
-    
-    if (decsep.Length() == 0) {
-        decsep.Printf(wxT("%lf"), 1.2);
-        decsep = decsep[(unsigned int)1];
-    }
-
-    result.Printf(wxT("%lf"), value);
-    result.Replace(decsep, wxT("."));
-
-    // Get rid of excessive decimal places
-    if (result.Contains(wxT(".")))
-        while (result.Right(1) == wxT("0"))
-            result.RemoveLast();
-    if (result.Right(1) == wxT("."))
-        result.RemoveLast();
-
-    return result;
-}
-
-double StrToDouble(const wxString& value)
-{
-    wxCharBuffer buf = value.ToAscii();
-    char *p=strchr(buf, '.');
-    if (p)
-        *p = localeconv()->decimal_point[0];
-
-    return strtod(buf, 0);
-}
-
-
-wxULongLong StrToLongLong(const wxString &value)
-{
-    return atolonglong(value.ToAscii());
-}
-
-
-wxString DateToAnsiStr(const wxDateTime &datetime)
-{
-    if (!datetime.IsValid())
-        return wxEmptyString;
-
-    return datetime.FormatISODate() + wxT(" ") + datetime.FormatISOTime();
-}
-
-
-wxString DateToStr(const wxDateTime &datetime)
-{
-    if (!datetime.IsValid())
-        return wxEmptyString;
-
-    return datetime.FormatDate() + wxT(" ") + datetime.FormatTime();
-}
-
-
-wxDateTime StrToDateTime(const wxString &value)
-{
-    wxDateTime dt;
-    /* This hasn't just been used. ( Is not infinity ) */
-    if ( !value.IsEmpty() )
-    dt.ParseDateTime(value);
-    return dt;
-}
-
-
-void CheckOnScreen(wxPoint &pos, wxSize &size, const int w0, const int h0)
-{
-    wxSize screenSize = wxGetDisplaySize();
-    int scrW = screenSize.x;
-    int scrH = screenSize.y;
-
-    if (pos.x < 0)
-        pos.x = 0;
-    if (pos.y < 0)
-        pos.y = 0;
-
-    if (pos.x > scrW-w0)
-        pos.x = scrW-w0;
-    if (pos.y > scrH-h0)
-        pos.y = scrH-h0;
-    
-    if (size.GetWidth() < w0)
-        size.SetWidth(w0);
-    if (size.GetHeight() < h0)
-        size.SetHeight(h0);
-
-    if (size.GetWidth() > scrW)
-        size.SetWidth(scrW);
-    if (size.GetHeight() > scrH)
-        size.SetHeight(scrH);
-}
-
-
-wxString qtString(const wxString& value)
-{
-    wxString result = value;	
-
-    result.Replace(wxT("\\"), wxT("\\\\"));
-    result.Replace(wxT("'"), wxT("\\'"));
-    result.Append(wxT("'"));
-    result.Prepend(wxT("'"));
-	
-    return result;
+    wxString str;
+    str.Printf(wxT("%d - %s"), id, name.BeforeFirst('\n').c_str());
+    return str;
 }
 
 
@@ -525,7 +345,7 @@ void DisplayHelp(wxWindow *wnd, const wxString &helpTopic, char **icon)
         firstCall=false;
         wxString helpdir=docPath + wxT("/") + settings->GetCanonicalLanguage();
 
-        if (!wxFile::Exists(helpdir + wxT("/pgadmin3.hhp")) &&
+        if (!wxFile::Exists(helpdir + wxT("/pgadmin3..hhp")) &&
 #if defined(__WXMSW__) || wxUSE_LIBMSPACK
             !wxFile::Exists(helpdir + wxT("/pgadmin3.chm")) &&
 #endif
@@ -555,31 +375,36 @@ void DisplayHelp(wxWindow *wnd, const wxString &helpTopic, char **icon)
         }
     }
 
+    wxString page;
+    int hashPos = helpTopic.Find('#');
+    if (hashPos < 0)
+        page = helpTopic + wxT(".html");
+    else
+        page = helpTopic.Left(hashPos) + wxT(".html") + helpTopic.Mid(hashPos);
+
     if (helpCtl)
     {
-        if (helpTopic == wxT("index"))
+        if (helpTopic == wxT("index.html"))
             helpCtl->DisplayContents();
         else
-            helpCtl->DisplaySection(helpTopic + wxT(".html"));
+            helpCtl->DisplaySection(page);
     }
     else
     {
         while (wnd->GetParent())
             wnd=wnd->GetParent();
     
-        frmHelp::LoadLocalDoc(wnd, helpTopic + wxT(".html"), icon);
+        frmHelp::LoadLocalDoc(wnd, page, icon);
     }
 }
 
 
 void DisplaySqlHelp(wxWindow *wnd, const wxString &helpTopic, char **icon)
 {
-    if (helpTopic.Left(8) == wxT("pgadmin/"))
-        DisplayHelp(wnd, helpTopic.Mid(8), icon);
-    else if (settings->GetSqlHelpSite().length() != 0) 
-        frmHelp::LoadSqlDoc(wnd, helpTopic  + wxT(".html"));
+    if (helpTopic.Left(3) == wxT("pg/") && settings->GetSqlHelpSite().length() != 0) 
+        frmHelp::LoadSqlDoc(wnd, helpTopic.Mid(3)  + wxT(".html"));
     else
-        DisplayHelp(wnd, wxT("pg/") + helpTopic, icon);
+        DisplayHelp(wnd, helpTopic, icon);
 }
 
 
