@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: sysSettings.cpp 3943 2005-01-10 15:30:26Z dpage $
+// RCS-ID:      $Id: sysSettings.cpp 4544 2005-10-14 13:06:59Z dpage $
 // Copyright (C) 2002 - 2005, The pgAdmin Development Team
 // This software is released under the Artistic Licence
 //
@@ -33,23 +33,54 @@ extern wxString docPath;
 sysSettings::sysSettings(const wxString& name) : wxConfig(name)
 {
     // Tip Of The Day
-    Read(wxT("ShowTipOfTheDay"), &showTipOfTheDay, TRUE); 
+    Read(wxT("ShowTipOfTheDay"), &showTipOfTheDay, true); 
     Read(wxT("NextTipOfTheDay"), &nextTipOfTheDay, 0); 
 
-    // Log
-    Read(wxT("LogFile"), &logFile, wxT("pgadmin.log")); 
+    // Log. Try to get a vaguely usable default path.
+    char *homedir;
+#ifdef __WXMSW__
+    char *homedrive;
+#endif
+
+    wxString deflog;
+    
+#ifdef __WXMSW__
+    homedrive = getenv("HOMEDRIVE");
+    homedir = getenv("HOMEPATH");
+#else
+    homedir = getenv("HOME");
+#endif
+
+    if (!homedir)
+        deflog = wxT("pgadmin.log");
+    else 
+    {
+        
+#ifdef __WXMSW__
+        deflog = wxString::FromAscii(homedrive);
+        deflog += wxString::FromAscii(homedir);
+        deflog += wxT("\\pgadmin.log");
+#else
+        deflog = wxString::FromAscii(homedir);
+        deflog += wxT("/pgadmin.log");
+#endif
+    }
+
+    Read(wxT("LogFile"), &logFile, deflog); 
     Read(wxT("LogLevel"), &logLevel, LOG_ERRORS);
+    sysLogger::logFile = logFile;
+    sysLogger::logLevel = logLevel;
 
     // Last Connection
     Read(wxT("LastServer"), &lastServer, wxT("localhost")); 
-    Read(wxT("LastDatabase"), &lastDatabase, wxT("template1")); 
+    Read(wxT("LastDatabase"), &lastDatabase, wxEmptyString); 
 	Read(wxT("LastDescription"), &lastDescription, wxT("PostgreSQL Server")); 
     Read(wxT("LastUsername"), &lastUsername, wxT("postgres")); 
     Read(wxT("LastPort"), &lastPort, 5432);
     Read(wxT("LastSSL"), &lastSSL, 0);
 
     // Show System Objects
-    Read(wxT("ShowSystemObjects"), &showSystemObjects, FALSE); 
+    Read(wxT("ShowSystemObjects"), &showSystemObjects, false); 
 
 //    Read(wxT("SqlHelpSite"), &sqlHelpSite, docPath + wxT("/en_US/pg/"));
     Read(wxT("SqlHelpSite"), &sqlHelpSite, wxT(""));
@@ -70,14 +101,14 @@ sysSettings::sysSettings(const wxString& name) : wxConfig(name)
     autoRowCountThreshold=Read(wxT("AutoRowCount"), 2000);
     Read(wxT("StickySql"), &stickySql, false);
     Read(wxT("DoubleClickProperties"), &doubleClickProperties, true);
+    Read(wxT("SuppressGuruHints"), &suppressGuruHints, false);
     Read(wxT("WriteUnicodeFile"), &unicodeFile, false);
-    Read(wxT("SearchPath"), &searchPath, wxEmptyString);
+    Read(wxT("SystemSchemas"), &systemSchemas, wxEmptyString);
     Read(wxT("MaxServerLogSize"), &maxServerLogSize, 100000L);
+    Read(wxT("Export/Unicode"), &exportUnicode, false);
+    Read(wxT("SlonyPath"), &slonyPath, wxEmptyString);
 
     wxString val;
-    Read(wxT("Export/Unicode"), &val, wxT("No"));
-    exportUnicode = StrToBool(val);
-
 #ifdef __WXMSW__
     Read(wxT("Export/RowSeparator"), &val, wxT("CR/LF"));
 #else
@@ -151,11 +182,13 @@ void sysSettings::Save()
     Write(wxT("Proxy"), proxy);
     Write(wxT("AutoRowCount"), autoRowCountThreshold);
     Write(wxT("WriteUnicodeFile"), unicodeFile);
-    Write(wxT("SearchPath"), searchPath);
+    Write(wxT("SystemSchemas"), systemSchemas);
     Write(wxT("MaxServerLogSize"), maxServerLogSize);
+    Write(wxT("SuppressGuruHints"), suppressGuruHints);
+    Write(wxT("SlonyPath"), slonyPath);
 
 
-    Write(wxT("Export/Unicode"), BoolToStr(exportUnicode));
+    Write(wxT("Export/Unicode"), exportUnicode);
     Write(wxT("Export/QuoteChar"), exportQuoteChar);
     Write(wxT("Export/ColSeparator"), exportColSeparator);
     if (exportRowSeparator == wxT("\r\n"))
@@ -197,6 +230,19 @@ void sysSettings::SetProxy(const wxString &s)
 }
 
 
+bool sysSettings::Read(const wxString& key, bool *val, bool defaultVal) const
+{
+    wxString str;
+    Read(key, &str, BoolToStr(defaultVal));
+	*val = StrToBool(str);
+	return true;
+}
+
+bool sysSettings::Write(const wxString &key, bool value)
+{
+    return Write(key, BoolToStr(value));
+}
+
 bool sysSettings::Write(const wxString &key, const wxPoint &value)
 {
     bool rc=wxConfig::Write(key + wxT("/Left"), value.x);
@@ -251,11 +297,13 @@ void sysSettings::SetNextTipOfTheDay(const int newval)
 void sysSettings::SetLogFile(const wxString& newval)
 {
     logFile = newval;
+    sysLogger::logFile = newval;
 }
 
 void sysSettings::SetLogLevel(const int newval)
 {
     logLevel = newval;
+    sysLogger::logLevel = newval;
 }
 
 //////////////////////////////////////////////////////////////////////////
